{% extends '@CpCreationTheme1/base.html.twig' %}
 {% block meta %}
     <meta name="robots" content="noindex,nofollow">
 {% endblock meta %}
{% block content %}
    <div id="header_payment" class="container">
        <h1 class="text-center introtext">{% trans %}payment.payment_return{% endtrans %}</h1>
    </div>
    <div class="grid-container">
        {% include 'payment/_shop_payment_payment_return.html.twig' with { msg: msg, error: error} %}
    </div>
{% endblock %}
