<!DOCTYPE html>
<html lang="{{ app.request.locale }}">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width,initial-scale=1.0">
    <title>{% block title %}{% trans from 'meta' %}homepage.title{% endtrans %}{% endblock %}</title>
    {% block stylesheets %}{% endblock %}
    {{ encore_entry_link_tags('app') }}
    <link rel="apple-touch-icon" sizes="180x180" href="{{ asset('bundles/cpcreationtheme1/images/favicon/apple-touch-icon.png') }}">
    <link rel="icon" type="image/png" sizes="32x32" href="{{ asset('bundles/cpcreationtheme1/images/favicon/favicon-32x32.png') }}">
    <link rel="icon" type="image/png" sizes="16x16" href="{{ asset('bundles/cpcreationtheme1/images/favicon/favicon-16x16.png') }}">
    <link rel="manifest" href="{{ asset('bundles/cpcreationtheme1/images/favicon/site.webmanifest') }}">
    <link rel="mask-icon" href="{{ asset('bundles/cpcreationtheme1/images/favicon/safari-pinned-tab.svg') }}" color="#5bbad5">
    <meta name="theme-color" content="#ffffff">
    <link rel="icon" type="image/x-icon" href="{{ asset('bundles/cpcreationtheme1/images/favicon/favicon.ico') }}"/>
    {% block meta %}
        <meta name="robots" content="noindex,nofollow">
    {% endblock meta %}
</head>
<body class="background-verify">
<header class="header-{{ app.request.get('_route') }}">
    <div class="full-height container">
        {% block header_top %}
            <div class="grid-container text-center">
                <img class="float-center logo-header animated fadeIn" src="{{ asset('bundles/cpcreationtheme1/images/logo.svg') }}" alt="{% trans from 'meta' %}company_name{% endtrans %}">
                <ul>
                    {% if locales | length > 0 %}
                        <li class="lang"><a href="{{ path('homepage'~'.fr' ) }}" title="FR">FR</a></li>
                        {% for locale in locales %}
                            <li class="lang"><a href="{{ path('verify.'~locale.locale ) }}" title="{{ locale.locale }}">{{ locale.locale|upper }}</a></li>
                        {% endfor %}
                    {% endif %}
                </ul>
                <p class="text-center animated fadeIn">{{ 'verify.text_legal'|trans|nl2br }}</p>
                <form action="{{ path('homepage') }}" method="post">
                    <button type="submit" class="btn animated fadeIn">{{ ('verify.enter')|trans }}</button>
                </form>
                <p class="text-center"><small>{{ 'verify.cookie'|trans|nl2br }}</small></p>
            </div>
        {% endblock header_top %}
    </div>
</header>
{% block javascripts %}{% endblock %}
{{ encore_entry_script_tags('app') }}
<!-- Global site tag (gtag.js) - Google Analytics -->
<script async src="https://www.googletagmanager.com/gtag/js?id=UA-114604668-XX"></script>
<script>
    window.dataLayer = window.dataLayer || [];
    function gtag(){dataLayer.push(arguments);}
    gtag('js', new Date());

    gtag('config', 'UA-114604668-XX');
</script>
</body>
</html>
