@import "~sweetalert2/dist/sweetalert2.min.css";

.swal2-confirm.shop {
    background-color: $colorShop !important;
}

.swal2-popup .swal2-styled:focus {
    box-shadow: none !important;
}

.swal2-popup.product-delivery {
    .swal2-title, .swal2-content {
        font-size: 1em;
    }
    .swal2-header {
        padding: 0;
    }
}
