.padding-20 {
  padding-top: 20px;
}

.padding-40 {
  padding-top: 40px;
}

.padding-50 {
  padding-top: 50px;
}
:focus {
    outline-style: none;
    box-shadow: none;
    border-color: transparent;
}
@media screen and #{breakpoint(xsxlarge)} {
  .xsxlarge-up-2 > .cell {
    width: 50%;
  }
}

@media screen and #{breakpoint(xlarge)} {
  .xlarge-up-3 > .cell {
    width: 33.3333%;
  }
}

@media screen and #{breakpoint(xxxlarge)} {
  .xxxlarge-up-4 > .cell {
    width: 25%;
  }
}

.citation {
  p {
    font-size: 1.3em;
    &.phrase {
      @media screen and #{breakpoint(xslarge down)} {
        font-size: 2em;
      }
      @media screen and #{breakpoint(large)} {
        font-size: 2.4em;
      }
    }
    text-align: center;
    &.author {
      text-align: right;
      font-style: italic;
      @media screen and #{breakpoint(xslarge down)} {
        font-size: 1.1em;
      }
      @media screen and #{breakpoint(large)} {
        font-size: 1.2em;
      }

    }
  }
}

.list-unstyled {
  list-style: none;
  margin: 0;
}

.line-picto {
  position: relative;
  z-index: 1;
  &:before {
    border-top: 1px solid $secondaryColor;
    content: "";
    margin: 0 auto;
    position: absolute;
    top: 50%;
    left: 0;
    right: 0;
    bottom: 0;
    width: 100%;
    z-index: -1;
  }
  img {
    padding: 0 30px;
    display: inline-block;
    background-color: $primary;
    height: 60px;
  }
}

.social__icon, [class^="social__icon"] {
  font-size: 1.4em;
  color: white;
  text-decoration: none;
  border-radius: 100%;
  width: 2.2em;
  height: 2.2em;
  text-align: center;
  display: flex;
  align-items: center;
  justify-content: center;
  &:hover {
    color: white;
  }
}

.social__icon--twitter {
  background-color: #32b9e7;

}

.social__icon--twitter:hover {
  background-color: #2b9dc4;
}

.social__icon--facebook {
  background-color: #4b70ab;
}

.social__icon--facebook:hover {
  background-color: #405f91;
}

.social__icon--instagram {
  background: #E518A1;
  background: -webkit-radial-gradient(-20px 40px, #ffda75 18%, #ff3a49 43%, #ff3a49 50%, #e518a1 70%, #6634e1 100%);
}

.social__icon--instagram:hover {
  background: #cd188c;
  background: -webkit-radial-gradient(-20px 40px, #cdab67 18%, #cd323f 43%, #cd363f 50%, #cd188c 70%, #6634e1 100%);
}

#scrollToTop {
  opacity: 0;
  width: 60px;
  position: fixed;
  bottom: 10px;
  right: 10px;
  z-index: 5;
  cursor: pointer;
  transition: opacity 0.5s ease-in-out;
  -moz-transition: opacity 0.5s ease-in-out;
  -webkit-transition: opacity 0.5s ease-in-out;
  color: $colorButtonScroll;
}

.separator {
  background-color: $primary;
  height: 150px;
  position: relative;
  margin-bottom: 50px;
  .grid-container {
    height: 100%;
  }
  .line-picto {
    height: 100%;
    img {
      position: absolute;
      margin: auto;
      top: 0;
      right: 0;
      bottom: 0;
      left: 0;
    }
  }
}

.butText {
  background: rgba(0, 0, 0, 0.3);
  position: absolute;
  color: #fff;
  //font-size: 1.3em;
  font-family: inherit;
  text-transform: uppercase;
  text-align: center;
  /* text-shadow: 0px 0px 3px rgba(0, 0, 0, .5); */
  top: 0px;
  left: 0px;
  width: 100%;
  height: 100%;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}

.butText {
  h1 {
    border: 2px solid $h1Image;
    padding: 10px 25px;
    color: $h1Image;
    z-index: 1000;
  }
  p {
    @media screen and #{breakpoint(medium down)} {
      max-width: 300px;
    }
    @media screen and #{breakpoint(large)} {
      max-width: 400px;
    }
    z-index: 1000;
  }
  .subtitle-h1 {
    @media screen and #{breakpoint(medium down)} {
      display: none;
    }
  }
}

.butFrame {
  overflow: hidden;
  position: relative;
  min-height: 600px;
  height: 50vh;
}

.sub-menu {
  margin: 0;
  width: 100%;
  @media screen and #{breakpoint(large)} {
    text-align: right;
  }
  @media screen and #{breakpoint(xslarge down)} {
    text-align: center;
  }
  li {
    font-size: 0.9rem;
    display: inline-block;
    list-style: none;
    text-align: center;
    &:hover {
      text-decoration: underline;
    }
  }
  a {
    padding: 5px 0 5px 12px;
    display: inline-block;
    width: 100%;
    outline: none;
    text-transform: uppercase;
    font-weight: 400;
    text-decoration: none;
    letter-spacing: .04em;
    color: black;
    &:hover {
      text-decoration: underline;
    }
    @media screen and #{breakpoint(medium down)} {
      font-size: 80%;
    }
  }
  a.active {
    font-weight: bold;
  }
}

.has-tip {
  border: 0;
}

/* Common style */
.instagram .photos figure {
  position: relative;
  box-shadow: 8px 8px 12px rgba(0, 0, 0, 0.59);
  overflow: hidden;
  text-align: center;
  cursor: pointer;
  height: 100%;
  &:after {
    content: "";
    display: block;
    padding-bottom: 100%;
  }
  &.insta-video {
    &:before {
      font-family: 'Font Awesome 5 Free';
      content: '\F144';
      position: absolute;
      left: 0;
      right: 0;
      top: 50%;
      font-size: 10em;
      color: white;
      transform: translateY(-50%);
    }
  }
}

.instagram .photos figure img {
  position: absolute;
  width: calc(100% + 10px);
  height: calc(100% + 10px);
  object-fit: cover;
  left: 0;
}

.instagram .photos figure figcaption {
  padding: 2em;
  color: #fff;
  text-transform: uppercase;
  font-size: 1.25em;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
}

.instagram .photos figure figcaption::before,
.instagram .photos figure figcaption::after {
  pointer-events: none;
}

.instagram .photos figure figcaption,
.instagram .photos figure figcaption > a {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}

/* Anchor will cover the whole item by default */
/* For some effects it will show as a button */
.instagram .photos figure figcaption > a {
  z-index: 1000;
  text-indent: 200%;
  white-space: nowrap;
  font-size: 0;
  opacity: 0;
}

.instagram .photos figure p {
  font-size: 12px;
  font-weight: 700;
}

.large-order-1 {
  .arrow-white {
    @media screen and #{breakpoint(large)} {
      position: absolute;
      width: 0;
      height: 0;
      top: 50%;
      transform: translateY(-50%);
      right: 0;
      margin: auto 0;
      border-top: 20px solid transparent;
      border-bottom: 20px solid transparent;
      border-right: 20px solid white;
    }
    @media screen and #{breakpoint(xslarge down)} {
      position: absolute;
      width: 0;
      height: 0;
      left: 0;
      right: 0;
      bottom: -10px;
      margin: 0 auto;
      border-top: 20px solid transparent;
      border-bottom: 20px solid transparent;
      border-right: 20px solid white;
      transform: rotate(90deg);
    }
  }
}

.medium-order-1 {
  .arrow-white {
    @media screen and #{breakpoint(medium)} {
      position: absolute;
      width: 0;
      height: 0;
      top: 50%;
      transform: translateY(-50%);
      right: 0;
      margin: auto 0;
      border-top: 20px solid transparent;
      border-bottom: 20px solid transparent;
      border-right: 20px solid white;
    }
    @media screen and #{breakpoint(small only)} {
      position: absolute;
      width: 0;
      height: 0;
      left: 0;
      right: 0;
      bottom: -10px;
      margin: 0 auto;
      border-top: 20px solid transparent;
      border-bottom: 20px solid transparent;
      border-right: 20px solid white;
      transform: rotate(90deg);
    }
  }
}

.large-order-2 {
  .arrow-white {
    @media screen and #{breakpoint(large)} {
      position: absolute;
      width: 0;
      height: 0;
      top: 50%;
      transform: translateY(-50%) rotate(180deg);
      left: 0;
      margin: auto 0;
      border-top: 20px solid transparent;
      border-bottom: 20px solid transparent;
      border-right: 20px solid white;
    }
    @media screen and #{breakpoint(xslarge down)} {
      position: absolute;
      width: 0;
      height: 0;
      left: 0;
      right: 0;
      bottom: -10px;
      margin: 0 auto;
      border-top: 20px solid transparent;
      border-bottom: 20px solid transparent;
      border-right: 20px solid white;
      transform: rotate(90deg);
    }
  }
}

.medium-order-2 {
  .arrow-white {
    @media screen and #{breakpoint(medium)} {
      position: absolute;
      width: 0;
      height: 0;
      top: 50%;
      transform: translateY(-50%) rotate(180deg);
      left: 0;
      margin: auto 0;
      border-top: 20px solid transparent;
      border-bottom: 20px solid transparent;
      border-right: 20px solid white;
    }
    @media screen and #{breakpoint(small only)} {
      position: absolute;
      width: 0;
      height: 0;
      left: 0;
      right: 0;
      bottom: -10px;
      margin: 0 auto;
      border-top: 20px solid transparent;
      border-bottom: 20px solid transparent;
      border-right: 20px solid white;
      transform: rotate(90deg);
    }
  }
}

.arrow-white.center {
  position: absolute;
  width: 0;
  height: 0;
  left: 0;
  right: 0;
  bottom: -10px;
  margin: 0 auto;
  border-top: 20px solid transparent;
  border-bottom: 20px solid transparent;
  border-right: 20px solid white;
  transform: rotate(90deg);
  z-index: 1;
}

.arrow-center {
  position: absolute;
  width: 0;
  height: 0;
  left: 0;
  right: 0;
  bottom: -10px;
  margin: 0 auto;
  border-top: 20px solid transparent;
  border-bottom: 20px solid transparent;
  border-right: 20px solid white;
  transform: rotate(90deg);
  z-index: 1;
}

.arrow-center.odd {
  border-top: 20px solid transparent;
  border-bottom: 20px solid transparent;
  border-right: 20px solid $backgoundColorLight;
}

.arrow-center.even {
  border-top: 20px solid transparent;
  border-bottom: 20px solid transparent;
  border-right: 20px solid white;
}

.fa-exclamation-triangle {
  color: red;
}

.title {
  h2 {
    margin-top: 20px;
  }
  .container {
    margin-top: 20px;
  }
  p {
    font-size: 120%;
  }
}
