@import '~@fortawesome/fontawesome-free/scss/fontawesome';
@import '~@fortawesome/fontawesome-free/scss/regular';
@import '~@fortawesome/fontawesome-free/scss/solid';
@import '~@fortawesome/fontawesome-free/scss/brands';

@font-face {
  font-family: 'icomoon';
  src:  url('../fonts/icomoon.eot?vz0eb');
  src:  url('../fonts/icomoon.svg?vz0eb#icomoon') format('svg'),
  url('../fonts/icomoon.woff?vz0eb') format('woff'),
  url('../fonts/icomoon.eot?vz0eb#iefix') format('embedded-opentype'),
  url('../fonts/icomoon.ttf?vz0eb') format('truetype');
  font-weight: normal;
  font-style: normal;
  font-display: block;
}

[class^="icon-"], [class*=" icon-"] {
  /* use !important to prevent issues with browser extensions that change fonts */
  font-family: 'icomoon' !important;
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;

  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.icon-square:before {
  content: "\e906";
}
.icon-arrow_l:before {
  content: "\e900";
}
.icon-arrow_r:before {
  content: "\e901";
}
.icon-diamond:before {
  content: "\e902";
}
.icon-facebook:before {
  content: "\e903";
}
.icon-instagram:before {
  content: "\e904";
}
.icon-twitter:before {
  content: "\e905";
}