#toast-container {
  top: 100px;
}

.toast{
  opacity: 1;
}
.toast-success {
  background-color: #5bbab3;
  opacity: 1 !important;
}
.toast-error, .toast-warning {
  background-color: #db733f;
  opacity: 1 !important;
}