import * as Toastr from 'toastr';
Toastr.options.closeButton = true;
Toastr.options.timeOut = 5000;
Toastr.options.preventDuplicates = true;
$('.notify-success').each(function () {
    let message = $(this).data('message');
    Toastr.success(message);
});

$('.notify-error').each(function () {
    let message = $(this).data('message');
    Toastr.error(message);
});