{% extends 'base.html.twig' %}
{% block meta %}
    <meta name="robots" content="noindex,nofollow">
{% endblock meta %}
{% block header_bottom %}
    <div class="grid-container title">
        <h1>{{ 'legal.title'|trans }}</h1>
        <div class="container">
            <p class="text-center">Merci de lire attentivement les présentes modalités d'utilisation du présent site
                avant de le parcourir.
                En vous connectant sur ce site, vous acceptez sans réserve les présentes modalités.</p>
        </div>
    </div>
{% endblock %}
{% block content %}
    <div class="grid-container">
        <section class="legals">
            <article>
                <h3>Édition du site internet</h3>
                <ul>
                    <li>Concepteur : SAS CP Création au capital de 375 000 €, 43 RUE DES FORGES 51200 EPERNAY - RCS : REIMS B 392 267 977 - TVA INTRA : FR40 392 267 977
                    </li>
                    {% if contact.editorCompany is not null %}
                        <li>
                            Éditeur : {{ contact.editorCompany }} - {{ contact.editorAddress }} {{ contact.editorPostal }} {{ contact.editorCity }} - RCS : {{ contact.editorRCS }} - TVA intra. : {{ contact.editorTva }}
                        </li>
                    {% endif %}
                    <li>Directeur de publication : {{ contact.company|upper }}</li>
                    <li>Responsable des mises à jour du contenu éditorial : {{ contact.company|upper }}</li>
                </ul>

                <h3>Hébergement du site</h3>
                <p>
                    L'hébergement du site est réalisé par la société OVH.<br>
                    SAS OVH<br>
                    Adresse : 2 rue Kellermann – BP 80157 – 59053 Roubaix Cedex 1 | France <br>
                    Tel : 1007 <br>
                    Site : https://www.ovh.com<br>
                </p>
                <h3>Propriétés intellectuelles</h3>
                <p>
                    © Tout le contenu du présent site, incluant, de façon non limitative, les graphismes, images,
                    textes,
                    vidéos, animations, sons, logos, gifs et icônes ainsi que leur mise en forme sont la propriété
                    exclusive
                    de la société Cp Création à l'exception des marques, logos ou contenus appartenant à d'autres
                    sociétés
                    partenaires ou auteurs.
                    Toute reproduction, distribution, modification, adaptation, retransmission ou publication, même
                    partielle, de ces différents éléments est strictement interdite sans l'accord exprès par écrit de Cp
                    Création. Cette représentation ou reproduction,
                    par quelque procédé que ce soit, constitue une contrefaçon sanctionnée par les articles L.3335-2 et
                    suivants du Code de la propriété intellectuelle. Le non-respect de cette interdiction constitue une
                    contrefaçon pouvant engager la responsabilité civile et pénale du contrefacteur.
                    En outre, les propriétaires des Contenus copiés pourraient intenter une action en justice à votre
                    encontre.</p>

                <h3>Informations et exclusion</h3>
                <p>
                    Cp Création met en œuvre tous les moyens dont elle dispose, pour assurer une information fiable et
                    une
                    mise à jour fiable de ses sites internet.
                    Toutefois, des erreurs ou omissions peuvent survenir. L'internaute devra donc s'assurer de
                    l'exactitude
                    des informations auprès de CP Création ou {{ contact.company|upper }}, et signaler toutes
                    modifications du site
                    qu'il jugerait utile.
                    CpCréation n'est en aucun cas responsable de l'utilisation faite de ces informations, et de tout
                    préjudice direct ou indirect pouvant en découler.</p>

                <h3>Données personnelles</h3>
                <p> Pour des besoins de statistiques, le présent site utilise des cookies. Il s'agit de petits fichiers
                    textes stockés sur votre disque dur afin d'enregistrer des données techniques sur votre
                    navigation.<br>
                    Aucune information personnelle n'est cédée à des tiers, seul CP Création
                    et {{ contact.company|upper }} ont
                    accès à ces informations.
                </p>
                {% if contact.committeeChampagneSiret %}
                    <h3>Loi AGEC</h3>
                        <p>Notre numéro d’identifiant unique délivré par l’ADEME, conformément aux dispositions de la loi AGEC, est le suivant : </p>
                        <p> <strong>Ressortissant du Comité de Champagne</strong> : {{ contact.committeeChampagneSiret }} </p>
                        {% endif %}
                    {% if contact.committeeChampagneIdentifiant %}
                        <p> <strong>Titulaire de l'identifiant unique</strong> : {{ contact.committeeChampagneIdentifiant }} </p>
                {% endif %}
                 <h4>* <a href="{{ path('private-policy') }}" title="{{ 'legal.button'|trans }}">Lire notre politique de
                        confidentialité.</a></h4>

                {% if contact.cgv is not null %}
                    <h4>* <a href="{{ path('cgv') }}" title="{{ 'cgv.button'|trans }}">Lire nos conditions générales de vente.</a></h4>
                {% endif %}
            </article>
        </section>
    </div>
{% endblock %}
