import Swal from "sweetalert2";

if (document.querySelector('.blockShop'))
{
    Swal.fire({
            title: document.querySelector('.blockShop-text').getAttribute('data-blockshop-title'),
            html: document.querySelector('.blockShop-text').getAttribute('data-blockshop-text'),
            icon: 'warning',
            allowOutsideClick: false,
            allowEscapeKey: false,
            customClass: {
                confirmButton: 'shop',
            },
        }
    )
}
