<!DOCTYPE html>
<html lang="{{ app.request.locale }}">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width,initial-scale=1.0">
    <title>{% block title %}{% trans from 'meta' %}homepage.title{% endtrans %}{% endblock %}</title>
    {{ encore_entry_link_tags('app') }}
    <link rel="apple-touch-icon" sizes="180x180"
          href="{{ asset('bundles/cpcreationtheme1/images/favicon/apple-touch-icon.png') }}">
    <link rel="icon" type="image/png" sizes="32x32"
          href="{{ asset('bundles/cpcreationtheme1/images/favicon/favicon-32x32.png') }}">
    <link rel="icon" type="image/png" sizes="16x16"
          href="{{ asset('bundles/cpcreationtheme1/images/favicon/favicon-16x16.png') }}">
    <link rel="manifest" href="{{ asset('bundles/cpcreationtheme1/images/favicon/site.webmanifest') }}">
    <link rel="mask-icon" href="{{ asset('bundles/cpcreationtheme1/images/favicon/safari-pinned-tab.svg') }}"
          color="#8c827a">
    <meta name="msapplication-TileColor" content="#8c827a">
    <meta name="theme-color" content="#FFFFFF">
    <link rel="icon" type="image/x-icon" href="{{ asset('bundles/cpcreationtheme1/images/favicon/favicon.ico') }}"/>
    {% block stylesheets %}{% endblock %}
    {% block meta %}
    {% endblock meta %}
</head>
<body>
<header id="header" class="{{ app.request.get('_route') }}">
    {% block header_top %}
    {% endblock %}
    <div id="navbar" class="animated{% if classMenu is defined %} {{ classMenu }} {% else %} white{% endif %} {% if subMenu is defined%} {% if subMenu %}subMenu{% endif %}{% endif %}">
        <div class="grid-container grid-x align-middle">
            <div class="small-1 medium-1 large-1 picto">
                <a href="{{ path('homepage') }}" title="{% trans from 'meta' %}homepage.title{% endtrans %}">
                    {% if classMenu is defined %}
                        {% if classMenu == 'black' %}
                            <img src="{{ asset('bundles/cpcreationtheme1/images/picto_n.svg') }}"
                                 alt="picto {% trans from 'meta' %}company_name{% endtrans %}">
                        {% endif %}
                    {% else %}
                        <img src="{{ asset('bundles/cpcreationtheme1/images/picto_blc.svg') }}"
                             alt="picto {% trans from 'meta' %}company_name{% endtrans %}">
                    {% endif %}
                </a>
            </div>
            <nav class="small-11 medium-11 large-11 {% if  classMenu is defined %}{{ classMenu }}{% endif %}">
                <input type="checkbox" id="nav" class="hidden"/>
                <label for="nav"
                       class="nav-open hide-for-large close {% if  classMenu is defined %}{{ classMenu }}{% endif %}"><i></i><i></i><i></i></label>
                <div class="nav-container grid-x align-center">
                    {{ render(controller('CpCreation\\VitiCore\\Bridge\\Symfony\\Bundle\\Controller\\Site\\MenuController::indexAction')) }}
                </div>
            </nav>
            {% block submenu %}
            {% endblock %}
        </div>
    </div>
    {% block header_bottom %}
    {% endblock %}
</header>
{% block content %}
{% endblock %}
<footer>
    {{ render(controller('CpCreation\\VitiCore\\Bridge\\Symfony\\Bundle\\Controller\\Site\\FooterController::indexAction')) }}
</footer>
{#<div id="scrollToTop"><i class="fas fa-chevron-circle-up fa-3x"></i></div>#}
{% block modal %}
{% endblock %}
{% include ('_flashMessage.html.twig') %}
{% block javascripts %}{% endblock %}
{{ encore_entry_script_tags('app') }}
<!-- Global site tag (gtag.js) - Google Analytics -->
<script async src="https://www.googletagmanager.com/gtag/js?id=UA-114604668-XX"></script>
<script>
    window.dataLayer = window.dataLayer || [];

    function gtag() {
        dataLayer.push(arguments);
    }

    gtag('js', new Date());

    gtag('config', 'UA-114604668-XX');
</script>
</body>
</html>
