#contact {
  margin: 50px 0;
  text-align: center;
  p {
    margin: 0;
  }
  #contactForm {
    background-color: $primary;
    padding: 10px;

    ::placeholder {
      color: black;
    }

    .contact-submit {
      background-color: white;
      color: black;
      padding: 10px 0;
      width: 100%;
      text-transform: uppercase;
      cursor: pointer;
    }
  }
  @media screen and #{breakpoint(small only)} {
    .address {
      margin-top: 60px;
    }
  }
  img {
    width:  400px;
    max-width: 80%;
    margin-bottom: 20px;
  }
}

[type='text'], [type='password'], [type='date'], [type='datetime'], [type='datetime-local'], [type='month'], [type='week'], [type='email'], [type='number'], [type='search'], [type='tel'], [type='time'], [type='url'], [type='color'], textarea {
  display: block;
  box-sizing: border-box;
  width: 100%;
  height: 2.4375rem;
  margin: 0 0 10px;
  padding: 0.5rem;
  border: 1px solid #cacaca;
  border-radius: 0;
  background-color: #fefefe;
  box-shadow: inset 0 1px 2px rgba(10, 10, 10, 0.1);
  font-family: inherit;
  font-size: 1rem;
  font-weight: normal;
  line-height: 1.5;
  color: #0a0a0a;
  transition: box-shadow 0.5s, border-color 0.25s ease-in-out;
}

.g-recaptcha{
  display: inline-block;
  width: 100%;
  div {
    width: 100% !important;
  }
}
