.background-verify {
    background-color: $primary;

    .logo-header {
        width: 60%;
        @media screen and #{breakpoint(medium down)} {
            width: 80%;
        }
    }

    header {
        padding-top: 100px;
    }

    ul {
        margin-left: 0;
        margin-top: 30px;
        list-style: none;

        li.lang {
            display: inline-block;

            a {
                font-weight: bold;
                color: white;
            }
        }

        li.lang + li.lang {
            a {
                &::before {
                    content: '/ ';
                }
            }
        }
    }

    a.btn, button[type="submit"] {
        animation-duration: 3s;
        padding: 10px 80px;
        color: #fff;
        font-size: 1.8em;
        cursor: pointer;
        @media screen and #{breakpoint(medium down)} {
            font-size: 1.2em;
        }
        background-color: black;
        text-decoration: none;
    }

    a.btn:hover, button[type="submit"]:hover {
        box-shadow: 8px 8px 12px rgba(0, 0, 0, .29);
    }

    p {
        color: #fff;
        animation-duration: 2.5s;
        margin-top: 50px;
        margin-bottom: 50px;
    }
}
