$color-red: #aa0000;
$color-green: #007200;
$color-gray: #6d6d6d;


// Colors
.ribbon.promo span {
    background-color: $color-red !important;
}

.ribbon.new span {
    background-color: $color-green !important;
}

.ribbon.soldout span {
    background-color: $color-gray !important;
}

.ribbon {
    position: absolute;
    top: 0;
    z-index: 20;
    overflow: hidden;
    width: 130px;
    height: 130px;
    text-align: right;
    left: 0px;
}

.ribbon span {
    font-size: 12px;
    text-transform: uppercase;
    color: #fff;
    text-align: center;
    font-weight: 700;
    line-height: 23px;
    transform: rotate(-45deg);
    width: 160px;
    display: block;
    box-shadow: 0 3px 10px -5px black;
    position: absolute;
    top: 37px;
    left: -31px;
}
