<div class="grid-container">
    <div class="line-picto text-center"><img src="{{ asset('bundles/cpcreationtheme1/images/picto_blc.svg') }}"
                                             alt="Picto {% trans from 'meta' %}company_name{% endtrans %}"></div>
    <div class="grid-x footer-content align-middle">
        <div class="contact small-12 large-4">
            <p>{{ contact.company }} <br/>
                {{ contact.address }} - {{ contact.postal }} {{ contact.city }}<br/>
                Tél. : <a href="tel:{{ contact.phone1 }}">{{ contact.phone1 }}</a><br/>
                {% if  contact.phone2 %}Tél. : <a href="tel:{{ contact.phone2 }}">{{ contact.phone2 }}</a>
                    <br/> {% endif %}
                {% if  contact.phone3 %}Fax : {{ contact.phone3 }}  <br/> {% endif %}
        </div>
        <div class="social small-12 large-4">
            <ul class="list-unstyled">
                {% if contact.twitter %}
                    <li><a target="_blank" href="{{ contact.twitter }}" class="social__icon--twitter"><i
                                class="fab fa-twitter"></i></a></li>{% endif %}
                {% if contact.facebook %}
                    <li><a target="_blank" href="{{ contact.facebook }}" class="social__icon--facebook"><i
                                class="fab fa-facebook-f"></i></a></li>{% endif %}
                {% if contact.instagram %}
                    <li><a target="_blank" href="{{ contact.instagram }}" class="social__icon--instagram"><i
                                class="fab fa-instagram"></i></a></li>{% endif %}
            </ul>
        </div>
        <div class="labels small-12 large-4">
            {% if labels | length > 0 %}
                {% set length = labels | length %}
                <div class="grid-x grid-margin-x small-up-{{ length }} medium-up-{{ length }} large-up-{{ length }}">
                    {% for label in labels %}
                        <div class="cell">
                            <img src="{{ asset(label.image.path | image_path) }}" alt="{{ label.text }}" {% if label.text %}data-tooltip-js{% endif %} class="top" tabindex="2"
                                 title="{{ label.text }}">
                        </div>
                    {% endfor %}
                </div>
            {% endif %}
        </div>
        <div class="small-12 text-center">
            <a href="{{ path('legals') }}">{{ 'legals'|trans([],'menu') }}</a>
        </div>
    </div>
</div>
