<section class="payment">
    <div class="grid-x grid-margin-x">
        <div class="cell small-4 text-right">
            <strong>Nom : </strong>
        </div>
        <div class="cell small-8 text-left">
            {{ payment.lastname }}
        </div>
    </div>
    <div class="grid-x grid-margin-x">
        <div class="cell small-4 text-right">
            <strong>Prénom : </strong>
        </div>
        <div class="cell small-8 text-left">
            {{ payment.firstname }}
        </div>
    </div>
    <div class="grid-x grid-margin-x">
        <div class="cell small-4 text-right">
            <strong>Rue :</strong>
        </div>
        <div class="cell small-8 text-left">
            {{ payment.street }}
        </div>
    </div>
    <div class="grid-x grid-margin-x">
        <div class="cell small-4 text-right">
            <strong>Code postal :</strong>
        </div>
        <div class="cell small-8 text-left">
            {{ payment.postalCode }}
        </div>
    </div>
    <div class="grid-x grid-margin-x">
        <div class="cell small-4 text-right">
            <strong>Ville :</strong>
        </div>
        <div class="cell small-8 text-left">
            {{ payment.city }}
        </div>
    </div>
    <div class="grid-x grid-margin-x">
        <div class="cell small-4 text-right">
            <strong>Mobile :</strong>
        </div>
        <div class="cell small-8 text-left">
            {{ payment.phone }}
        </div>
    </div>
    <div class="grid-x grid-margin-x">
        <div class="cell small-4 text-right">
            <strong>E-mail :</strong>
        </div>
        <div class="cell small-8 text-left">
            {{ payment.email }}
        </div>
    </div>
    <div class="grid-x grid-margin-x">
        <div class="cell small-4 text-right">
            <strong>Référence Facture ou commande :</strong>
        </div>
        <div class="cell small-8 text-left">
            {{ payment.reference }}
        </div>
    </div>
    <div class="grid-x grid-margin-x">
        <div class="cell small-4 text-right">
            <strong>Montant :</strong>
        </div>
        <div class="cell small-8 text-left">
            {{ (payment.amount/100) | number_format(2) }} € TTC
        </div>
    </div>
    <form class="cell small-6 text-right" action="{{ data.URL }}" method="POST">
        {% for key,item in data %}
            {% if key != 'URL' %}
                <input type="hidden" name="{{ key }}" value="{{ item }}">
            {% endif %}
        {% endfor %}
        <a href="{{ path('payment_item', {id : payment.id }) }}" class="button back-payment"><i class="fas fa-angle-left"></i> {% trans %} payment.back {% endtrans %}</a>
        {% if cart.paymentMethod.method != "sherlock" %}
            <button type="submit" class="button "><i
                        class="fas fa-credit-card"></i> {% trans %} shop.pay_order {% endtrans %}</button>
        {% else %}
            <button type="submit" name="CB" class="button "><i
                        class="fas fa-credit-card"></i> {% trans %} shop.pay_order {% endtrans %}<input type="IMAGE" name="CB" border="0"/>
            </button>
        {% endif %}
    </form>
</section>
