{% extends 'base.html.twig' %}
{% block title %}{{'cgv.title' | trans()}}{% endblock %}
{% block meta %}
    <meta name="robots" content="noindex,nofollow">
{% endblock meta %}
{% block header_bottom %}
    <div class="grid-container title">
        <h1>{{'cgv.title' | trans()}}</h1>
        <div class="container">
            <p class="text-center">Merci de lire attentivement les présentes modalités d'utilisation du présent site
                avant de le parcourir.
                En vous connectant sur ce site, vous acceptez sans réserve les présentes modalités.</p>
        </div>
    </div>
{% endblock %}
{% block content %}
    <section id="cgv">
        <div class="grid-container">
            <div class="grid-x grid-padding-x grid-margin-x grid-padding-y grid-margin-y align-center-middle">
                <div class="cell small-12 medium-12 large-12">
                    {% if contact.cgv %}
                        {{ contact.cgv | raw }}
                    {% endif %}
                    {% if contact.committeeChampagneSiret %}
                        <p>Notre numéro d’identifiant unique délivré par l’ADEME, conformément aux dispositions de la loi AGEC, est le suivant : </p>
                        <p> <strong>Ressortissant du Comité de Champagne</strong> : {{ contact.committeeChampagneSiret }} </p>
                    {% endif %}
                    {% if contact.committeeChampagneIdentifiant %}
                        <p> <strong>Titulaire de l'identifiant unique</strong> : {{ contact.committeeChampagneIdentifiant }} </p>
                    {% endif %}
                </div>
            </div>
        </div>
    </section>
{% endblock %}
