.shop-isotope {
    .cuvee a.button-shop.add-cart {
        width: 100%;
        padding: 0.85em 0.8em;
        font-size: 0.75em;
    }

    .no-visible {
        visibility: hidden;
        opacity: 0;
    }
    &:after{
        content: '';
        display: block;
        clear: both;
    }
    overflow: hidden;
}

.category-filter {
    position: relative;

    &:before {
        content: '';
        width: 50%;
        margin: 0 auto;
        top: 0;
        left: 0;
        right: 0;
        position: absolute;
        border-top: 4px solid $secondaryColor;
    }

    h4.categories {
        margin-bottom: 20px;
        display: inline;
    }

    padding: 20px 10px 10px;

    .category-filter-active {
        font-weight: bold;
        position: relative;

        &:before {
            content: '';
            height: 50%;
            top: 50%;
            transform: translateY(-50%);
            width: 2px;
            background-color: #ad8b5c;
            left: 0;
            position: absolute;
        }
    }

    ul.menu {
        margin-top: 10px;
        @media screen and #{breakpoint(xslarge down)} {
            overflow: hidden;
        }
        clear: both;
        max-height: 0;
        transition: max-height .2s ease-out;

        li {
            color: black;
            padding: 5px 11px;
            cursor: pointer;
            display: block;
            width: 100%;

            &:hover {
                color: $secondaryColor;
            }
        }
    }

    .menu-icon-filter {
        cursor: pointer;
        display: inline-block;
        padding: 20px 20px 20px;
        position: absolute;
        top: 50%;
        transform: translateY(-50%);
        user-select: none;
        transition: top .2s ease-out;

        .navicon {
            background: #333;
            display: block;
            height: 2px;
            position: relative;
            transition: background .2s ease-out;
            width: 18px;

            &:before, &:after {
                background: #333;
                content: '';
                display: block;
                height: 100%;
                position: absolute;
                transition: all .2s ease-out;
                width: 100%;
            }

            &:before {
                top: 5px;
            }

            &:after {
                top: -5px;
            }
        }
    }

    .menu-btn {
        display: none;
    }

    .menu-btn:checked ~ .menu {
        max-height: 240px;
    }

    .menu-btn:checked ~ .menu-icon-filter {
        top: 0;
        transform: none;
        padding: 32px 20px 20px;
    }

    .menu-btn:checked ~ .menu-icon-filter .navicon {
        background: transparent;

        &:before {
            transform: rotate(-45deg);
        }

        &:after {
            transform: rotate(45deg);
        }
    }

    .menu-btn:checked ~ .menu-icon-filter:not(.steps) .navicon {
        &:before, &:after {
            top: 0;
        }
    }
}

@media screen and #{breakpoint(large)} {
    .category-filter .menu-icon-filter {
        display: none;
    }
}

h4.shop-categories, h4.shop-title-categories {
    text-transform: uppercase;
}

.swiper-slide {
    .category-favorite[data-first] {
        position: relative;
        &:before {
            font-family: 'Font Awesome 5 Free';
            position: absolute;
            content: '\f005';
            left: -20px;
            font-size: 10px;
            top: 50%;
            transform: translateY(-50%);
        }
    }
}
.category-filter-item[data-first] {
    i {
        line-height: 5px;
        font-size: 10px;
        top: 50%;
        transform: translateY(-50%);
    }
}


.container-input{
    width: 100%;
    .quicksearch{
        border-radius: 10px;
        width: 80%;
        max-width: 600px;
        margin: 0 auto;
        margin-bottom: 20px;
    }

}
