.shop {
    .shop-informations-supp{
        margin-bottom: 40px;
    }
    .help{
        font-size: 0.85em;
        text-align: left;
        color: black;
    }
    .active-code-price {
        border: 1px solid;
        padding: 10px;
        text-align: center;

        h5 {
            margin: 0;
        }

        margin-bottom: 40px;
    }

    .form_cart_promo {
        position: relative;
    }

    #cart_promo {
        width: 50%;
        margin-left: auto;
        margin-right: 35px;
    }

    .verif-promo {
        position: absolute;
        right: 0;
        top: 3px;
    }

    .partner-code {
        background-color: $primary;
        padding: 20px;
        margin-bottom: 50px;
    }

    #codePriceForm {
        [type='text'] {
            height: 3.1rem;
        }

        h5 {
            margin: 0 auto;
            margin-bottom: 20px;
        }

        text-align: center;

        .button {
            position: absolute;
            top: 0;
            right: 0;
            width: auto;
        }

        .form-group {
            width: 100%;
        }

        .input-code {
            position: relative;
            margin: 0 auto;
        }

        @media only screen and (min-width: 970px) {
            .form-group {
                width: 100%;
            }
            .input-code {
                width: 50%;
            }
            .btn-code-price {
                text-align: left;
            }
        }
    }

    h3 {
        margin-bottom: 40px;
        text-transform: uppercase;
    }
    h3.shop-title-category{
        margin-bottom: 10px;
    }
    .shop-description-category{
        margin-bottom: 40px;
    }
    article {
        position: relative;

        img {
            max-height: 400px;
            width: auto;
        }
    }

    p.variant-name {
        padding-top: 0.55rem;
        padding-bottom: 0.3rem;
    }

    .total-without-fdp {
        align-items: center;
        padding: 20px 0 0 0px;
        background-color: $colorShop;
        margin-bottom: 40px;
        text-align: center;

        p {
            color: white;
            font-size: 140%;
            margin-bottom: 20px;
        }

        span.total-products {
            color: $colorShop;
            background-color: white;
            text-align: center;
            padding: 10px 8px;

        }

        @media only screen and (min-width: 970px) {
            p:first-child {
                text-align: right;
            }
            p:not(:first-child) {
                text-align: left;
            }
        }
        @media only screen and (max-width: 970px) {
            p {
                text-align: center
            }
        }
    }

    .total-products {
        font-weight: bold;
    }

    .variant-row {
        height: 60px;
    }

    .variant-qty {
        animation-duration: 4s;
        animation-fill-mode: forwards;
    }

    .form-cart {
        margin-top: 120px;
        text-align: center;
        align-items: center;

        .cart-empty {
            text-align: center
        }

        .delete-cart-row {
            color: $primary;
            cursor: pointer;
        }
    }

    .header-form-cart {
        background-color: $colorShop;
        margin-bottom: 20px;

        div {
            text-align: center;
            padding: 10px;
            color: white;
        }
    }

    .old-price {
        text-decoration: line-through;
        color: #9c241d;
        font-size: 80%;
    }

    #cart_items {
        input {
            margin: 0;
        }

        .form-group {
            margin-bottom: 20px;
        }

        margin-bottom: 100px;
    }

    .info-product {
        cursor: pointer;
    }

    .total-order-label {
        p {
            text-align: right;
            font-weight: bold;
        }
    }

    .total-order-price {
        p {
            text-align: right;
        }
    }

    button.button {
        width: 100%;
        font-size: 110%;
    }

    .form-error {
        color: #9c241d;
    }

    .cuvee {
        .img-cuvee {
            position: relative;

            .awards {
                position: absolute;
                right: 0;

                img {
                    margin: 5px;
                    display: block;
                    max-width: 55px;
                    image-rendering: -webkit-optimize-contrast;
                    @media only screen and (max-width: 640px) {
                        width: 50px;
                    }
                }
            }
        }
    }
    hr {
        margin: 1rem auto;
    }
    [type='file'], [type='checkbox'], [type='radio']{
        margin-bottom: 0;
    }
    .title-category-cuvees{
        width: 100%;
        margin-top: 50px;
        text-align: center;
    }
}

.cartCheckout {
    text-align: left;

    .radio {
        text-align: left;
    }

    p.shipping-info {
        font-size: 90%;
        text-align: left;
    }
}

.output_postal {
    display: none;
    border: 1px solid;
    padding: 15px;
    position: absolute;
    background-color: white;
    max-height: 300px;
    overflow-y: auto;

    a {
        display: block;
        color: #000;
        text-align: left;

        &:hover {
            background-color: #c0c0c0;
        }
    }
}

//Theme 3
.shop.theme3 {
    .article-info {
        margin-top: 20px;
        background-color: $primary;
        padding: 15px;
        color: white;
        position: relative;
    }

    .checkbox {
        label {
            margin: 16px 0px;
            line-height: 1.3em;
        }
    }

    h4.address {
        background-color: #CDCDCD;
        padding: 10px;
        margin-bottom: 10px;
    }

    span.variant-price {
        font-size: 150%;
        color: white;
        font-weight: bold;
    }

    a.button-shop {
        margin-top: 10px;
        text-decoration: none;
        background-color: $primary;
        color: white;

        &:hover {
            background-color: $secondaryColor;
        }
    }

    .article-details {
        position: absolute;
        left: 0;
        right: 0;
        bottom: 8px;
        height: 20px;

        span {
            font-style: italic;
            color: white;

            &:hover {
                text-decoration: underline;
            }
        }
    }

    button.button {
        width: 100%;
        font-size: 110%;
        background-color: $primary;
    }

    label a {
        color: black;
    }

    #header_payment {
        margin-top: 50px;
    }

    ul.shop-category {
        li {
            display: inline-block;
        }
    }

    h3 {
        a {
            color: #000000;

            &:hover {
                color: gray;
            }
        }
    }
}

label.cart_deliveryMethod {
    margin: 10px 0;
}
.deliveryMethod_description{
    display: block;
    font-size: 0.9em;
    font-style: italic;
}
.input_cart_deliveryMethod {
    margin: 0;
}

.label_cart_deliveryMethod {
    font-weight: bold;
}

.shop.theme3 {
    button.button {
        background-color: $colorShop;
    }

    .article-info {
        background-color: $primary;
    }

    a.button-shop {
        position: relative;
        text-transform: uppercase;
        border-radius: 50px;
        width: 80%;
        margin: 0 auto;
        margin-bottom: 0;
        align-self: end;
        color: #ffffff;
        transition: all .3s;
        background-color: transparent;
        overflow: hidden;

        &:hover {
            color: white;
            background-color: transparent !important;

            &:after {
                background: #000;
                height: 100%;
                width: 200%;
            }
        }

        &:before {
            background-color: $colorShop;
            width: 100%;
            left: 0;
            content: "";
            height: 100%;
            border-radius: 50px;
            position: absolute;
            top: 0;
            z-index: -1;
        }

        &:after {
            -webkit-transition: all .3s;
            -moz-transition: all .3s;
            -o-transition: all .3s;
            transition: all .3s;
            left: -50%;
            border-radius: 50px;
            transform: skew(50deg);
            transition-duration: .6s;
            transform-origin: top left;
            width: 0;
            content: "";
            height: 100%;
            position: absolute;
            top: 0;
            z-index: -1;
        }
    }

    .shop .header-form-cart div {
        color: black;
    }

    article {
        position: relative;
        overflow: hidden;
        &::before {
            content: "";
            position: absolute;
            border-top: 4px solid var(--color-border);
            width: 50px;
            height: 10px;
            right: 0;
            @media screen and #{breakpoint(small only)} {
                left: 0;
                margin: 0 auto;
                width: 50%;
            }
        }

        .cuvee {
            padding-top: 20px;
        }

        img {
            @media screen and #{breakpoint(small only)} {
                max-height: 200px;
            }
        }
    }

    .infos_bulle {
        margin-bottom: 30px;

        .info_bulle {
            position: relative;

            .icon {
                border-radius: 80px;
                background-color: $colorShop;
                width: 80px;
                height: 80px;
                margin: 0 auto;
                position: relative;
                font-size: 2em;
                @media screen and #{breakpoint(small only)} {
                    font-size: 1.1em;
                    width: 40px;
                    height: 40px;
                }

                i {
                    color: white;
                    top: 50%;
                    position: absolute;
                    left: 0;
                    right: 0;
                    transform: translateY(-50%);
                }
            }

            &.payment {
                .icon {
                    background-color: #4f4a4a;
                }
            }

            &.discount {
                .icon {
                    background-color: #d72a36;
                }
            }

            span {
                display: block;
            }

            .title {
                @media screen and #{breakpoint(small only)} {
                    font-size: 75%;
                }
            }

            .descr {
                color: grey;
                font-size: 90%;
                @media screen and #{breakpoint(small only)} {
                    font-size: 70%;
                }
            }
        }
    }

}

.shop .header-form-cart {
    background-color: $primary;
}

.shop.theme3 a.button-shop:hover {
    background-color: $primary;
}

section.shop {
    h4 {
        font-size: 1.2em;
        @media screen and #{breakpoint(large down)} {
            font-size: 1.1em;
        }
    }

    .article-quality {
        display: block;
        height: 24px;
    }
}

.shop.theme3 a.js-cd-panel-trigger {
    text-decoration: none;
    background-color: transparent;
    color: black;
    text-align: center;
    font-weight: 400;
    margin: 0;
    padding-right: 0;

    &:hover {
        //background-color: black;
        text-decoration: underline;
    }
}

.shop.theme3 .article-info {
    background-color: transparent;

    p {
        color: #000;
    }
}

.shop.theme3 {
    .cuvee-name, .article-quality, span.variant-price {
        color: #000;
    }
}

.shop.theme3 .article-info {
    margin-top: 0;
    background-color: #fff;
    padding: 0;
    color: #fff;
    position: relative;
    text-align: right;
}

.variant-row-vo {
    margin-bottom: .6rem;
    height: auto;
}

.variant-row-vo span {
    color: #000;
    text-transform: uppercase;
    font-size: .9rem;
}

.shop .variant-row {
    margin-bottom: .6rem;
}

.shop .variant-row {
    height: 40px;
}

.shop p.variant-name, select.variant-type {
    padding-bottom: .1rem;
    margin-bottom: 0;
}

sup {
    color: #000;
}

sup {
    top: -.5em;
}

sub, sup {
    font-size: 75%;
    line-height: 0;
    position: relative;
    vertical-align: baseline;
}

.variant-price span {
    color: #000;
    font-size: 1.2rem;
}

.cuvee-name {
    margin-bottom: 20px;
    h6{
        display: block;
        color: var(--color-cuvee);
        text-transform: uppercase;
        font-weight: 700;
    }
    span {
        display: block;
        color: #000;
        text-transform: uppercase;
        font-size: 1rem;
        font-weight: 700;

        &.header {
            font-size: 1rem;
            font-weight: normal;
        }

        &.quality {
            font-weight: 400;
            font-size: 0.8rem;
            color: var(--color-cuvee);
        }
    }

    @media screen and #{breakpoint(small only)} {
        text-align: center;
        margin-top: 15px;
    }
}

.shop.theme3 span.variant-price {
    font-size: 1.2rem;
}

.shop #codePriceForm [type='text'] {
    border-radius: 10px;
}

.shop #codePriceForm .button {
    border-top-right-radius: 10px;
    border-bottom-right-radius: 10px;

    &:hover {
        background: #000;
    }
}

.shop .header-form-cart {
    border-radius: 10px;
}

#cart_items_form {
    h4 {
        border-radius: 10px;
        small{
           letter-spacing: 0rem;
            font-size: 12px;
            color: black;
        }
    }
}

#cart_items_form button.button {
    position: relative;
    text-transform: uppercase;
    border-radius: 50px;
    width: 100%;
    margin-bottom: 0;
    color: #ffffff;
    transition: all .3s;
    background-color: transparent;
    overflow: hidden;

    &:hover {
        color: white;
        background-color: transparent !important;

        &:after {
            background: #000;
            height: 100%;
            width: 200%;
        }
    }

    &:before {
        background-color: $colorShop;
        width: 100%;
        left: 0;
        content: "";
        height: 100%;
        border-radius: 50px;
        position: absolute;
        top: 0;
        z-index: -1;
    }

    &:after {
        -webkit-transition: all .3s;
        -moz-transition: all .3s;
        -o-transition: all .3s;
        transition: all .3s;
        left: -50%;
        border-radius: 50px;
        transform: skew(50deg);
        transition-duration: .6s;
        transform-origin: top left;
        width: 0;
        content: "";
        height: 100%;
        position: absolute;
        top: 0;
        z-index: -1;
    }
}

.total-products-submenu {
    a.total {
        &::after {
            content: " /";
        }
    }

    @media screen and #{breakpoint(small only)} {
        & {
            font-size: 0.82em;
        }
    }
}

.left-informations {
    display: flex;
    flex-direction: column;
}

.secure-logos {
    margin-top: auto;
    margin-left: auto;
    margin-right: auto;

    img {
        @media screen and #{breakpoint(large down)} {
            margin-top: 40px;
            max-width: 300px;
        }
    }
}

.title {
    &.payment {
        margin-top: 50px;
    }

    .block-mark {
        text-align: center;
        margin-bottom: 50px;
        position: relative;

        img {
            margin-bottom: 20px;
            width: 70%;
            max-width: 500px;
        }

        &::after {
            content: '';
            position: absolute;
            width: 5%;
            min-width: 30px;
            height: 2px;
            background-color: black;
            margin: 0 auto;
            bottom: 0;
            left: 0;
            right: 0;
        }
    }
}

.countRest-award {
    border-radius: 80px;
    background-color: $colorShop;
    width: 40px;
    height: 40px;
    margin: 0 auto;
    position: relative;
    font-size: 1em;
    color: white;
    text-align: center;
    line-height: 40px;
    margin-top: 20px;
    vertical-align: middle;
}

.article-other-info {
    margin-top: 10px;
}

section.invoice{
    width: 70%;
    margin: 0 auto;
    margin-bottom: 50px;
    h4{
        margin-bottom: 20px;
    }
}

.show-more-list
{
    a{
        position: relative;
        &::after{
            font-family: "Font Awesome 5 Free";
            position: absolute;
            content: '\f107';
            right: 0;
        }
    }
}
.category-group{
    position: relative;
    &::before{
        position: absolute;
        content: '';
        width: 50%;
        height: 1px;
        left:0;
        top: 0;
        right: 0;
        margin: 0 auto;
        text-align: center;
        background-color:#cacaca;
    }
    .category-group-content{
        padding-top: 8px;
    }
    .hide-list-method {
        position: relative;
        overflow: hidden;
        line-height: 1em;
        height: auto;
        max-height: 5em;
        transition: max-height 0.2s ease-in-out;
        &.active{
            line-height: 1em;
            height: auto;
            max-height: 2000px;
        }
    }
    .show-more-list{
        a{
            position: relative;
            text-transform: uppercase;
            color: black;
            transition: all .3s;
            background-color: transparent;
            overflow: hidden;
            border-radius: 10px;
            display: inline-block;
            vertical-align: middle;
            border: 1px solid transparent;
            font-family: inherit;
            -webkit-appearance: none;
            line-height: 1;
            text-align: center;
            cursor: pointer;
            text-decoration: none;
            width: 80%;
            max-width: 300px;
            padding: 0.85em 0.8em;
            font-size: 0.70em;
            margin-bottom: 10px;

            &:before{
                background-color: #a1a1a1;
                width: 100%;
                left: 0;
                content: "";
                height: 100%;
                border-radius: 50px;
                position: absolute;
                top: 0;
                z-index: -1;
            }
            &:after{
                -webkit-transition: all .3s;
                -moz-transition: all .3s;
                -o-transition: all .3s;
                transition: all .3s;
                left: -50%;
                border-radius: 50px;
                transform: skew(50deg);
                transition-duration: .6s;
                transform-origin: top left;
                width: 0;
                content: "";
                height: 100%;
                position: absolute;
                top: 0;
                z-index: -1;
            }
            &:hover{
                color: white;
                background-color: transparent !important;
                &:after{
                    background: #ad8b5c;
                    height: 100%;
                    width: 200%;
                }
            }
            span{
                pointer-events: none;
            }
        }
    }

}

.drink-ribbon {
    width: 100%;
    text-align: center;
    margin: 20px 0 0 0;
    padding: 15px;
    background-color: #f5f5f5;
    color: grey;
    text-transform: uppercase;
    font-weight: 700;
    p {
        margin-top: 5px;
        margin-bottom: 0;
        font-size: 1em;
        @media screen and #{breakpoint(small only)} {
            font-size: 0.8em;
        }
    }
    img {
        width: 40%;
        max-width: 650px;
        @media screen and #{breakpoint(medium down)} {
            width: 80%;
        }
        @media screen and #{breakpoint(small only)} {
            width: 100%;
        }
    }
}
