{% extends 'base.html.twig' %}
{% block meta %}
    <meta name="robots" content="noindex,nofollow">
{% endblock meta %}
{% block header_bottom %}
    <div class="grid-container title">
        <h1>{{ 'privacy_policy.title' | trans }}</h1>
    </div>
{% endblock %}
{% block content %}
    <div class="grid-container">
        <section class="legals">
            <article>
                <h3>Introduction</h3>
                <p>
                    Nous (« nous ») nous soucions de la vie privée des utilisateurs (l’« utilisateur » ou « vous ») de
                    notre site Internet (le « Site ») et nous nous engageons à protéger les informations que les
                    utilisateurs partagent avec nous lorsqu’ils utilisent notre Site (collectivement, les « Propriétés
                    numériques »), et nous nous engageons pleinement à protéger et à utiliser vos informations
                    conformément à la loi applicable.
                    Cette Politique de confidentialité décrit nos pratiques en matière de recueil, d'utilisation et de
                    divulgation de vos informations par le biais de nos propriétés numériques (les « Services »),
                    lorsque vous accédez aux Services depuis votre appareil.
                    Avant d'accéder ou d'utiliser l'un de nos Services, veuillez lire attentivement cette Politique de
                    confidentialité et vous assurer que vous comprenez parfaitement nos pratiques concernant vos
                    informations. Si vous lisez et comprenez pleinement cette Politique de confidentialité, et que vous
                    restez opposé(e) à nos pratiques, vous devez immédiatement et cesser toute utilisation de nos
                    Propriétés numérique et de nos Services. En utilisant nos Services, vous acceptez les conditions de
                    cette Politique de confidentialité et le fait de continuer à utiliser les Services constitue votre
                    acceptation de cette Politique de confidentialité et de tout amendement à celle-ci.
                </p>
                <p>Dans la présente Politique de confidentialité, vous trouverez des explications sur les questions
                    suivantes :</p>
                <ul class="list">
                    <li>- Les informations que nous recueillons</li>
                    <li>- Comment nous recueillons les informations</li>
                    <li>- Comment nous recueillons les informations</li>
                    <li>- Pourquoi nous recueillons les informations</li>
                    <li>- Avec qui nous partageons les informations</li>
                    <li>- Où sont stockées les informations</li>
                    <li>- Combien de temps sont conservées les informations</li>
                    <li>- Comment nous protégeons les informations</li>
                    <li>- Modifications ou mises à jour de la Politique de confidentialité</li>
                </ul>
                <h3>Les informations que nous recueillons</h3>
                <p>
                    Les informations non identifiées et non identifiables, qui peuvent être recueillies lorsque vous
                    utilisez nos Services (les « Informations non
                    personnelles »). Les informations non personnelles ne nous permettent pas d'identifier la personne
                    auprès de qui elles ont été recueillies. Les Informations non personnelles que nous recueillons
                    consistent principalement en des informations techniques et des informations d'utilisation agrégées.
                </p>
                <p>
                    Les informations permettant de vous identifier individuellement, c’est-à-dire les informations qui
                    vous identifient ou qui peuvent, moyennant un effort raisonnable, vous identifier (les
                    « Informations personnelles »). Les Informations personnelles que nous recueillons par le biais de
                    nos Services sont notamment le nom, le prénom, l'adresse e-mail, le numéro de téléphone, l'adresse
                    IP ou d'autres informations demandées à chaque fois que nécessaire. Si nous combinons des
                    Informations personnelles avec des Informations non personnelles, nous traiterons les informations
                    combinées comme des Informations personnelles aussi longtemps qu'elles resteront combinées.
                </p>
                <h3>Comment nous recueillons les informations</h3>
                <p>
                    Nous recueillons des informations lorsque vous utilisez les Services. Lorsque vous visitez nos
                    Propriétés numériques ou que vous utilisez nos Services, nous pouvons recueillir, collecter et
                    enregistrer ces utilisations, sessions et informations connexes.
                </p>
                <p>
                    Nous recueillons les informations que vous nous fournissez volontairement. Par exemple, nous
                    recueillons les informations que vous nous fournissez lorsque vous nous contactez directement par
                    n'importe quel canal de communication (par exemple lorsque vous nous envoyez un e-mail contenant un
                    retour d'information, une réponse à une offre d'emploi publiée sur le site).
                </p>
                <h3>Pourquoi nous recueillons les informations</h3>
                <p>Nous utilisons vos Informations personnelles aux fins suivantes : <br/>
                    - Pour développer, personnaliser et améliorer nos Services <br/>
                    - Pour répondre à vos réactions, demandes et requêtes et vous apporter notre assistance <br/>
                    - Pour analyser les schémas de demande et d'utilisation <br/>
                    - À d'autres fins internes, de recherche ou de statistiques <br/>
                </p>
                <h3>Avec qui nous partageons les informations</h3>
                <p>Nous pouvons partager vos informations avec nos fournisseurs de services, afin d'exploiter nos
                    Services (Actuellement, nous pouvons partager vos informations avec Google pour le suivi statistique
                    de notre site internet et Axeptio pour la gestion des consentements de cookies)</p>
                <strong>Cookies</strong>
                <p>
                    Lorsque vous visitez ou accédez à notre Service, nous autorisons certains tiers à utiliser des
                    balises web, des cookies, des pixels invisibles, des scripts, des balises et d'autres technologies
                    et services d'analyse (les « Technologies de suivi »). Ces Technologies de suivi peuvent permettre à
                    des tiers de recueillir automatiquement des informations vous concernant afin d'améliorer la manière
                    dont vous naviguez sur nos Propriétés numériques, d'améliorer les performances de nos Propriétés
                    numériques et de personnaliser votre expérience sur nos Propriétés numériques, ainsi qu'à des fins
                    de sécurité et de prévention de la fraude.
                </p>
                <p>Nous ne partagerons pas votre adresse e-mail, ni toute autre Information personnelle, avec des
                    sociétés de publicité en ligne ou des réseaux publicitaires sans votre consentement.</p>
                <h3>Où sont stockées les informations</h3>
                <p>
                    <strong>Informations non personnelles</strong></br>
                    Veuillez noter que les partenaires et les fournisseurs de services à qui
                    nous faisons confiance, sont situés dans le monde entier. Toutes les Informations non personnelles
                    que nous recueillons sont stockées et traitées dans diverses juridictions à travers le monde, aux
                    fins détaillées dans la présente Politique de confidentialité.
                </p>
                <p>
                    <strong>Informations personnelles</strong></br>
                    Les Informations personnelles sont conservées, traitées et stockées en France Métropolitaine.
                </p>
                <h3>Combien de temps sont conservées les informations </h3>
                <p>
                    Veuillez noter que nous conservons les informations que nous recueillons aussi longtemps que
                    nécessaire pour fournir les Services et pour nous conformer à nos obligations légales ou
                    contractuelles envers vous, résoudre les litiges et faire respecter nos accords.<br/>
                    Nous pouvons rectifier, compléter ou supprimer des informations incomplètes ou inexactes, à tout
                    moment et à notre entière discrétion.
                </p>
                <h3>Comment nous protégeons les informations</h3>
                <p>
                    Le service d'hébergement de nos Propriétés numériques met à notre disposition la plateforme en ligne
                    qui nous permet de vous fournir le Service. Vos données peuvent être stockées par l'intermédiaire
                    des applications de stockage de données, de bases de données ou générales de notre fournisseur
                    d'hébergement. Il stocke vos informations sur des serveurs sécurisés derrière un pare-feu et offre
                    un accès sécurisé HTTPS à la plupart de ses services
                </p>
                <h3>Modifications ou mises à jour de la Politique de confidentialité</h3>
                <p>
                    Nous pouvons réviser cette politique de confidentialité à chaque fois que nécessaire, à notre seule
                    discrétion, et la version la plus récente sera toujours affichée sur notre site web (comme indiqué
                    dans la rubrique « Dernière révision »). Nous vous encourageons à consulter régulièrement la
                    présente Politique de confidentialité pour prendre connaissance de toute modification. En cas de
                    changements importants, nous publierons sur notre site web un avis pour annoncer ces changements. Si
                    vous continuez à utiliser les Services après la notification de modifications sur notre site web,
                    cela constituera votre reconnaissance de, et votre consentement à, ces modifications de la Politique
                    de confidentialité et votre accord à être lié(e) par les conditions de ces modifications.
                </p>
                <h3>Nous contacter</h3>
                <p>Si vous avez des questions d'ordre général sur les Services ou les informations que nous recueillons
                    à votre sujet, ou sur la manière dont nous les utilisons, contactez-nous à l'aide de notre
                    formulaire de contact.
                </p>
            </article>
        </section>
    </div>
{% endblock %}
