import tippy from 'tippy.js';
import 'core-js/stable';
import 'regenerator-runtime/runtime';
const template = document.getElementById('template');

tippy('[data-tooltip-js]', {
    content: (reference) => reference.getAttribute('title'),
    allowHTML: true
});
