$primary : #333333;
$backgoundColorLight : #f5f5f9;
$colorShop: $primary;
$panelContent: white;
$secondaryColor: #dfca20;

// ---- Couleurs du menu ---- //
$menu: white;
$footer: white;
$menuHover: gray;
$menuOpenHover: black;
$colorButtonScroll: black;
$h1Image: white;
// -- Image accueil -- //
$colorEffectImage: #8c827a;
$colorEffectImageGradient1: #8c827a;
$colorEffectImageGradient2: gray;
$colorEffectImageGradientRgba1: rgba(72,76,97,0);
$colorEffectImageGradientRgba2: rgba(72,76,97,0.8);
$colorTextEffectImage: white;


// ---- Couleurs des titres et textes du site ---- //
$text: white;

