{% for message in app.flashes('success') %}
    <div class="notify-success" data-message="{{ message }}"></div>
{% endfor %}

{% for messages in app.flashes(['warning', 'error']) %}
    {% for message in messages %}
        <div class="notify-error" data-message="{{ message }}"></div>
    {% endfor %}
{% endfor %}