picture.lozad {
    display: block;
    min-height: 1rem;
    &.loaded {
        img.transparent {
            display: none;
        }
    }
}
figure.before-lozad{
    overflow: hidden;
    img{
        filter: blur(1rem);
        opacity: 0.1;
    }

}

.no-view{
    display: none;
    visibility: hidden;
}
