{% if locales | length > 0 %}
    <div class="lang hide-for-large">
        <a href="{{ path('homepage'~'.fr' ) }}">FR</a>
        {% for locale in locales %}
            <a href="{{ path('homepage.'~locale.locale ) }}" title="{{ locale.locale }}">{{ locale.locale }}</a>
        {% endfor %}
    </div>
{% endif %}
<ul class="medium-12 large-12 main">
    <li class="hide-for-large">
        <a href="{{ path('homepage') }}">{{ 'accueil'|trans([],'menu') }}</a>
    </li>
    <li class="dropdown">
        <a href="#" data-scroll-ignore>{{ 'maison'|trans([],'menu') }}</a>
        <ul>
            <li>
                <a href="{{ path('home') }}">{{ 'maison'|trans([],'menu') }}</a>
            </li>
            <li><a href="{{ path('seasons') }}">{{ 'seasons'|trans([],'menu') }}</a></li>
        </ul>
    </li>
    <li><a href="{{ path('cuvees') }}">{{ 'cuvees'|trans([],'menu') }}</a></li>
    <li class="dropdown">
        <a href="#" data-scroll-ignore>{{ 'news'|trans([],'menu') }}</a>
        <ul>
            <li><a href="{{ path('news') }}">{{ 'news'|trans([],'menu') }}</a></li>
            <li><a href="{{ path('library') }}">{{ 'gallery'|trans([],'menu') }}</a></li>
        </ul>
    </li>
    <li><a href="{{ path('shop') }}">{{ 'boutique'|trans([],'menu') }}</a></li>
    <li><a href="{{ path('payment') }}">{{ 'payment'|trans([],'menu') }}</a></li>
    {% if (cottages| length > 0) and (cottages| length < 2) %}
        <li><a href="{{ path('cottage', {slug: cottages[0].slug}) }}">{{ 'gite'|trans([],'menu') }}</a></li>
    {% elseif cottages| length > 1 %}
        <li class="dropdown">
            <a href="#" data-scroll-ignore>{{ 'gite'|trans([],'menu') }}</a>
            <ul>
                {% for cottage in cottages %}
                    <li><a href="{{ path('cottage', { slug: cottage.slug}) }}">{{ cottage.title }}</a></li>
                {% endfor %}
            </ul>
        </li>
    {% endif %}
    <li class="dropdown">
        <a href="#" data-scroll-ignore>{{ 'contact'|trans([],'menu') }}</a>
        <ul>
            <li><a href="{{ path('find-us') }}">{{ 'find-us'|trans([],'menu') }}</a></li>
            <li><a href="{{ path('contact') }}">{{ 'contact'|trans([],'menu') }}</a></li>
        </ul>
    </li>
    {% if locales | length > 0 %}
        <li class="lang show-for-large"><a href="{{ path('homepage'~'.fr' ) }}">FR</a></li>
        {% for locale in locales %}
            <li class="lang show-for-large"><a href="{{ path('homepage.'~locale.locale ) }}" title="{{ locale.locale }}">{{ locale.locale }}</a></li>
        {% endfor %}
    {% endif %}
</ul>
