#navbar {
    @media screen and #{breakpoint(large down)} {
        padding-bottom: 4px;
    }
    @media screen and #{breakpoint(xslarge down)} {
        &.subMenu {
            padding-bottom: 4px;
        }
    }

    p {
        margin-bottom: 0;
    }

    top: -140px;
}

nav {
    text-align: right;
    @media screen and #{breakpoint(large)} {
        .nav-container {
            display: block !important;

        }
        border-bottom: 1px solid;
        border-color: $menu;
        &.black {
            border-bottom: 1px solid;
            border-color: black;
        }
    }
    @media screen and #{breakpoint(xslarge down)} {
        text-align: right;
        [type='checkbox'] + label {
            margin-top: 10px;
            margin-right: 0;
            padding-right: 0;
        }
    }

    ul.main {
        li.lang + li.lang {
            a {
                &::before {
                    content: '/ ';
                }

                padding: 12px 0 12px 2px;
            }
        }

        margin: 0;

        li {
            @media screen and #{breakpoint(xslarge down)} {
                &.dropdown {
                    padding: 0;
                    margin-bottom: 0;

                    > a {
                        display: none;
                        opacity: 0;
                        visibility: hidden;
                    }

                    ul {
                        margin-left: 0;
                    }
                }
            }
            @media screen and #{breakpoint(large)} {
                &.dropdown {
                    z-index: 1000;
                    text-align: center;

                    &:hover ul {
                        display: block;
                        opacity: 1;
                        visibility: visible;
                    }

                    > a::after {
                        content: ' ▾ ';
                        display: inline-block;
                        margin-left: 5px;
                    }

                    ul {
                        margin-left: 0;
                        padding: 0;
                        position: absolute;
                        top: 46px;
                        left: 0;
                        -webkit-box-shadow: none;
                        -moz-box-shadow: none;
                        box-shadow: none;
                        display: none;
                        opacity: 0;
                        visibility: hidden;
                        -webkit-transiton: opacity 0.2s;
                        -moz-transition: opacity 0.2s;
                        -ms-transition: opacity 0.2s;
                        -o-transition: opacity 0.2s;
                        -transition: opacity 0.2s;
                        box-shadow: 0 2px 5px 0 rgba(0, 0, 0, 0.16), 0 2px 10px 0 rgba(0, 0, 0, 0.12);

                        li {
                            width: 200px;
                            background: black;
                            display: block;

                            &:hover {
                                background: $secondaryColor;

                                a {
                                    color: #fff;
                                }
                            }

                            a {
                                width: 100%;
                                padding: 10px;
                                color: #fff;
                            }
                        }
                    }
                }
            }
            position: relative;
            font-size: 0.9rem;
            display: inline-block;

            &:not(:first-child) {
                @media screen and #{breakpoint(large)} {
                    //margin-left: 1px;
                }
            }

            a {
                @media screen and #{breakpoint(large)} {
                    padding: 12px 0 12px 18px;
                }
                display: inline-block;
                width: 100%;
                outline: none;
                text-transform: uppercase;
                font-weight: 600;
                text-decoration: none;
                letter-spacing: .04em;
                color: $menu;

                &:hover {
                    @media screen and #{breakpoint(xslarge down)} {
                        color: $menuOpenHover;
                    }
                    @media screen and #{breakpoint(large)} {
                        color: $secondaryColor;
                    }

                    text-decoration: none;
                }
            }
        }
    }

    @media screen and #{breakpoint(large)} {
        &.black {
            ul li a {
                color: black;

                &:hover {
                    color: $secondaryColor;
                }
            }

            ul li {
                &:not(:first-child) {
                    &::before {
                        color: black;
                    }
                }
            }
        }
    }

    ul.lang {
        text-align: right;

        li {
            @media screen and #{breakpoint(xslarge down)} {
                margin-left: 0;
            }

            &:first-letter {
                font-size: 100%;
            }

            &:not(:first-child) {
                &::before {
                    content: "/ ";
                    color: $menu;
                }
            }

            a {
                text-transform: uppercase;
            }
        }
    }
}

@media screen and #{breakpoint(xslarge down)} {
    .nav-container {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        height: 100vh;
        width: 100%;
        z-index: -1;
        background: $primary;
        opacity: 0;
        transition: all .2s ease;

        .lang {
            margin-top: 30px;
            text-align: center;

            a {
                color: $menu;
                text-transform: uppercase;
            }

            a + a {
                &::before {
                    content: '/ ';
                }

                padding: 12px 0 12px 2px;
            }
        }

        ul.main {
            margin-left: 0;
            position: absolute;
            top: 50%;
            transform: translateY(-50%);
            width: 100% !important;

            li {
                display: block;
                float: none;
                width: 100%;
                text-align: center;
                margin-bottom: 10px;
                padding: 8px 0;
                /*  &:nth-child(1) a {
                    transition-delay: 0.2s;
                  }
                  &:nth-child(2) a {
                    transition-delay: 0.3s;
                  }
                  &:nth-child(3) a {
                    transition-delay: 0.4s;
                  }
                  &:nth-child(4) a {
                    transition-delay: 0.5s;
                  }
                  &:nth-child(5) a {
                    transition-delay: 0.6s;
                  }
                  &:nth-child(6) a {
                    transition-delay: 0.7s;
                  }*/
                a {

                    @media (orientation: landscape) {
                        padding: 1px 25px;
                    }
                    opacity: 0;
                    color: $menu;
                    font-weight: 600;
                    transform: translateY(-20px);
                    transition: all .1s ease;
                    padding: 0;
                }
            }
        }

        ul.lang {
            width: 100%;
            position: absolute;
            top: 50px;
            @media (orientation: landscape) {
                top: 20px;
            }
            text-align: center;
            color: $menu;

            li {
                width: auto;
                display: inline-block;

                a {
                    padding: 0;
                }

                &:not(:first-child) {
                    &::before {
                        content: "/ ";
                    }
                }
            }
        }
    }
    .nav-open {
        position: relative;
        right: 0px;
        display: block;
        width: 38px;
        height: 18px;
        cursor: pointer;
        z-index: 9999;
        border-radius: 50%;

        &.black {
            i {
                background: black;
            }
        }

        i {
            display: block;
            width: 20px;
            height: 2px;
            background: $menu;
            border-radius: 2px;
            margin-left: 14px;

            &:nth-child(1) {
                //margin-top: 16px;
            }

            &:nth-child(2) {
                margin-top: 4px;
                opacity: 1;
            }

            &:nth-child(3) {
                margin-top: 4px;
            }

        }
    }
}

#nav:checked + .nav-open {
    transform: rotate(45deg);

    i {
        background: $menu;
        transition: transform .2s ease;

        &:nth-child(1) {
            transform: translateY(6px) rotate(180deg)
        }

        &:nth-child(2) {
            opacity: 0;
        }

        &:nth-child(3) {
            transform: translateY(-6px) rotate(90deg)
        }
    }
}

#nav:checked ~ .nav-container {
    z-index: 9990;
    opacity: 1;

    ul li a {
        opacity: 1;
        transform: translateY(0);
    }
}

.sticky {
    z-index: 100000;
    position: fixed;
    top: 0 !important;
    left: 0;
    width: 100%;
    transition: all 0.5s ease-in 0s;
    -webkit-box-shadow: 6px 10px 28px -13px rgba(0, 0, 0, 0.75);
    -moz-box-shadow: 6px 10px 28px -13px rgba(0, 0, 0, 0.75);
    box-shadow: 6px 10px 28px -13px rgba(0, 0, 0, 0.75);

    nav {
        border-color: black;
    }
}

.white {
    .sub-menu {
        a {
            color: white;
        }
    }
}

.white.sticky {
    background-color: black;

    nav {
        border-bottom: 1px solid;
        border-color: white;
        color: white;
    }

    .sub-menu {
        a {
            color: white;
        }
    }

    &:not(.subMenu) {
        nav {
            border: none;
        }
    }
}

.black.sticky {
    background-color: white;

    &:not(.subMenu) {
        nav {
            border: none;
        }

    }
}

.hidden {
    display: none;
}

.total-products-submenu {
    @media screen and #{breakpoint(large)} {
        margin-left: auto;
    }
    @media screen and #{breakpoint(xslarge down)} {
        margin: 0 auto;
    }
}
