{% extends 'base.html.twig' %}
{% block title %}{% trans from 'meta' %}payment.title{% endtrans %}{% endblock %}
{% block meta %}
    <meta name="robots" content="index,follow">
    <meta name="description" lang="{{ app.request.locale }}"
          content="{% trans from 'meta' %}payment.description{% endtrans %}">
    <meta property="og:site_name" content="{% trans from 'meta' %}payment.title{% endtrans %}">
    <meta property="og:title" content="{% trans from 'meta' %}payment.title{% endtrans %}">
    <meta property="og:type" content="website">
    <meta property="og:url" content="{{ app.request.uri }}">
    <meta property="og:image" content="{{ absolute_url('bundles/cpcreationtheme1/images/logo.jpg') }}">
    <meta property="og:locale" content="{{ app.request.locale }}">
    <meta property="og:image:type" content="image/jpeg">
    <meta property="og:image:width" content="600">
    <meta property="og:image:height" content="450">
    <meta property="og:description"
          content="{% trans from 'meta' %}payment.description{% endtrans %}">
    <link rel="canonical" href="{{  absolute_url(path('payment')) }}" >
{% endblock meta %}
{% block header_bottom %}
    <div class="grid-container title">
        <h1>{{ 'payment'|trans([],'menu') }}</h1>
        <div class="container">
            <p class="text-center">{% trans %}news.subtitle{% endtrans %}</p>
        </div>
    </div>
{% endblock %}
{% block content %}
    <div class="grid-container">
        <div class="cell small-12">
            <form id="payment-form" action="{{ path('payment') }}" method="POST">
                <div class="grid-x">
                    <div class="small-6">
                        {{ form_row(form.lastname) }}
                    </div>
                    <div class="small-6">
                        {{ form_row(form.firstname) }}
                    </div>
                </div>
                <div class="grid-x">
                    <div class="small-12">
                        {{ form_row(form.street) }}
                    </div>
                </div>
                <div class="grid-x">
                    <div class="small-6">
                        {{ form_row(form.postalCode) }}
                    </div>
                    <div class="small-6">
                        {{ form_row(form.city) }}
                    </div>
                </div>
                <div class="grid-x">
                    <div class="small-6">
                        {{ form_row(form.phone) }}
                    </div>
                    <div class="small-6">
                        {{ form_row(form.email) }}
                    </div>
                </div>
                <div class="grid-x ">
                    <div class="cell small-12">
                        {{ form_row(form.reference) }}
                    </div>
                </div>
                <div class="grid-x ">
                    <div class="cell small-12 amount">
                        {{ form_row(form.amount) }}
                    </div>
                </div>
                {{ form_rest(form) }}
                <button class="submit button payment" type="submit">
                    <strong>{{ ('payment.secure-space')|trans|upper }}</strong></button>
                {% if config.isDisableLogoBank == false %}
                    <div class="secure-logos text-center">
                        {% if paymentMethod.method == 'e-transactions' %}
                            <img src="{{ asset('bundles/cpcreationviticore/images/payment/e-transactions.jpg') }}"
                                 alt="Paiement sécurisé - E-transactions">
                        {% endif %}
                        {% if paymentMethod.method == 'systempay' %}
                            <img src="{{ asset('bundles/cpcreationviticore/images/payment/systempay.jpg') }}"
                                 alt="Paiement sécurisé - SystemPay">
                        {% endif %}
                        {% if paymentMethod.method == 'sherlock' %}
                            <img src="{{ asset('bundles/cpcreationviticore/images/payment/sherlock.jpg') }}"
                                 alt="Paiement sécurisé - Sherlock">
                        {% endif %}
                        {% if paymentMethod.method == 'sogecommerce' %}
                            <img src="{{ asset('bundles/cpcreationviticore/images/payment/logo-sogecommerce.jpg') }}"
                                 alt="Paiement sécurisé - SogeCommerce">
                        {% endif %}
                        {% if paymentMethod.method == 'monetico' %}
                            <img src="{{ asset('bundles/cpcreationviticore/images/payment/monetico.jpg') }}"
                                 alt="Paiement sécurisé - Monetico">
                        {% endif %}
                    </div>
                {% endif %}
            </form>
        </div>
    </div>

{% endblock %}
