{% extends 'base.html.twig' %}
 {% block meta %}
     <meta name="robots" content="noindex,nofollow">
 {% endblock meta %}
{% block content %}
    <div id="header_payment" class="container">
        <h1 class="text-center introtext">{% trans %}payment.payment_banktransfert{% endtrans %}</h1>
    </div>
    <div class="grid-container">
        {% include 'payment/_shop_payment_banktransfert.html.twig' with { cart: cart} %}
    </div>
{% endblock %}
