const routes = require('../../../../../../public/js/fos_js_routes.json');
import Routing from '../../../../../../vendor/friendsofsymfony/jsrouting-bundle/Resources/public/js/router.min.js';
Routing.setRoutingData(routes);

import $ from 'jquery';
import './_polyfill';
import Foundation from 'foundation-sites';
import SmoothScroll from 'smooth-scroll';
import './_responsiveBackground';
import './_scrollToTop';
import './_sticky';
import './_menu';
import './_swiper';
import './_map';
import './_notification';
import './_news';
import './_isotope';
import './_shop';
import './_panel';
import './_popup';
import './_blockShop';
import './_lozad';
import './_tooltip';
import './_show-more-method';
global.jQuery = $;
$(document).foundation();

$.ajaxSetup({
    timeout: 5000 //Time in milliseconds
});

import '../../../../viti-core/src/Bridge/Symfony/Bundle/Resources/public/css/site/style.scss';
import Recaptcha from '../../../../viti-core/src/Bridge/Symfony/Bundle/Resources/public/js/site/Recaptcha';
Recaptcha.init();
new SmoothScroll('a[href*="#"]', {
    // Selectors
    ignore: '[data-scroll-ignore]', // Selector for links to ignore (must be a valid CSS selector)
    header: null, // Selector for fixed headers (must be a valid CSS selector)
    speed: 500, // Integer. How fast to complete the scroll in milliseconds
    offset: 123, // Integer or Function returning an integer. How far to offset the scrolling anchor location in pixels
    easing: 'easeInOutCubic', // Easing pattern to use
});
