@charset "UTF-8";
//$grid-container : 970px;
$breakpoints: (
        small: 0,
        medium: 640px,
        xslarge: 860px,
        large: 970px,
        xsxlarge: 1120px,
        xlarge: 1200px,
        xxlarge: 1440px,
        xxxlarge: 1660px,
);


@import "~foundation-sites/assets/foundation";
@import "fonts";
@import "~animate.css";
/*@import "~aos/src/sass/aos";*/
@import "~swiper/dist/css/swiper";
@import "~toastr/toastr.scss";
@import '~tippy.js/dist/tippy.css';
//@import "colors.scss";
@import 'custom-properties';
@import "form_error";
@import "body.scss";
@import "menu";
@import "header";
@import "animation";
@import "content";
@import "helpers";
@import "img_effect";
@import "swiper";
@import "map";
@import "form";
@import "notification";
@import "verify";
@import "popup";
@import 'shop.scss';
@import 'shop_category.scss';
@import 'cdpanel.scss';
@import 'checkout.scss';
@import 'ribbon.scss';
@import 'payment.scss';
@import 'sweetAlert.scss';
@import 'tooltip.scss';
@import 'lozad';
@import 'video';
