{% extends 'base.html.twig' %}
{% block title %}{% trans from 'meta' %}shop.title{% endtrans %}{% endblock %}
{% block meta %}
    <meta name="robots" content="index,follow">
    <meta name="description" lang="{{ app.request.locale }}"
          content="{% trans from 'meta' %}shop.description{% endtrans %}">
    <meta property="og:site_name" content="{% trans from 'meta' %}shop.title{% endtrans %}">
    <meta property="og:title" content="{% trans from 'meta' %}shop.title{% endtrans %}">
    <meta property="og:type" content="website">
    <meta property="og:url" content="{{ app.request.uri }}">
    <meta property="og:locale" content="{{ app.request.locale }}">
    <meta property="og:image" content="{{ absolute_url('bundles/cpcreationtheme1/images/logo.jpg') }}">
    <meta property="og:image:type" content="image/jpeg">
    <meta property="og:image:width" content="600">
    <meta property="og:image:height" content="450">
    <meta property="og:description"
          content="{% trans from 'meta' %}shop.description{% endtrans %}">
    <link rel="canonical" href="{{ absolute_url(path('shop')) }}">
{% endblock meta %}
{% block header_bottom %}
    <div class="grid-container title">
        <h1>{% trans %}shop.title{% endtrans %}</h1>
        <div class="container">
            <p class="text-center subtitle">{% trans %}shop.subtitle{% endtrans %}</p>
            {% if info is defined %}
                <p class="text-center">{{ info|raw }}</p>
            {% endif %}
        </div>
    </div>
{% endblock %}
{% block submenu %}
    {% set taxe = 'TTC' %}
    {% if priceGroups|length > 1 %}
        {% if app.session.get('groupByDefault') != true %}
            {% set taxe =  app.session.get('groupPrice')|get_ht_or_ttc %}
        {% endif %}
    {% endif %}
    <p class="total-products-submenu"><a class="total" href="#my-order"><i
                    class="fas fa-cart-arrow-down"></i> {% trans %}shop.total_product{% endtrans %} :
            <strong><span class="total-products-price">0.00</span></strong> €</a>
        <a class="shipping" href="#total-order"><i class="fas fa-box"></i> {% trans %}shop.total_shipping{% endtrans %}
            :
            <strong><span class="total-order-shipping">0.00</span></strong> €</a>
    </p>
{% endblock %}
{% block content %}
    {% include '_shop_content.html.twig' with {'products': products, 'config' : config, 'categories' : categories} %}
    <div class="drink-ribbon">
        <img src="{{ asset('bundles/cpcreationtheme1/images/bandeau-vente-alcool.png') }}" alt="{{ 'shop.alcool'|trans() }}" />
        <p>{{ 'shop.alcool'|trans() }}</p>
    </div>
    <div id="scrollToTop"><i class="fas fa-chevron-circle-up fa-3x"></i></div>
{% endblock %}
{% block modal %}
    {% if popup %}
        {% include '_popup.html.twig' with { 'popup' : popup} only %}
    {% endif %}
{% endblock %}
{% block javascripts %}
    <script type="application/javascript"
            src="{{ asset('bundles/bazingajstranslation/js/translator.min.js') }}"></script>
    <script type="application/javascript" src="{{ asset('js/translations/config.js') }}"></script>
    <script type="application/javascript" src="{{ asset('js/translations/'~ app.request.locale~'.js') }}"></script>
{% endblock %}
