.swiper-sub-menu, .swiper-sub-menu-cottage, .swiper-category {
    a {

        &.active {
            font-weight: bold !important;
        }
    }

    width: 100%;
    text-align: center;

    .swiper-wrapper {
        width: 100%;

        .swiper-slide {
            display: -webkit-box;
            display: -ms-flexbox;
            display: -webkit-flex;
            display: flex;
            -webkit-box-pack: center;
            -ms-flex-pack: center;
            -webkit-justify-content: center;
            justify-content: center;
            -webkit-box-align: center;
            -ms-flex-align: center;
            -webkit-align-items: center;
            align-items: center;

            a {
                outline: none;
                font-size: 0.8em;
                text-transform: uppercase;
                font-weight: 400;
                text-decoration: none;
                letter-spacing: .04em;
                color: black;

                &:hover {
                    text-decoration: underline;
                }
            }

            @media screen and #{breakpoint(medium down)} {
                font-size: 70%;
            }
        }
    }

    @media screen and #{breakpoint(large)} {
        margin-top: 5px;
        margin-bottom: 5px;
    }

    .swiper-button-prev {
        background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2027%2044'%3E%3Cpath%20d%3D'M0%2C22L22%2C0l2.1%2C2.1L4.2%2C22l19.9%2C19.9L22%2C44L0%2C22L0%2C22L0%2C22z'%20fill%3D'%23002536'%2F%3E%3C%2Fsvg%3E");
        left: 0 !important;
        right: auto;

    }

    .swiper-button-next {
        background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2027%2044'%3E%3Cpath%20d%3D'M27%2C22L27%2C22L5%2C44l-2.1-2.1L22.8%2C22L2.9%2C2.1L5%2C0L27%2C22L27%2C22z'%20fill%3D'%23002536'%2F%3E%3C%2Fsvg%3E");
        right: 0 !important;
        left: auto;
    }

    .swiper-button-prev, .swiper-button-next {
        position: absolute;
        top: 50%;
        width: 20px;
        height: 15px;
        margin-top: -7px;
        z-index: 10;
        cursor: pointer;
        background-size: 20px 15px;
        background-position: center;
        /* background-repeat: no-repeat; */
    }

    .swiper-button-prev {
        left: 0 !important;
        right: auto;

    }

    .swiper-button-next {
        right: 0 !important;
        left: auto;
    }
}

.swiper-button-prev {
    background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2027%2044'%3E%3Cpath%20d%3D'M0%2C22L22%2C0l2.1%2C2.1L4.2%2C22l19.9%2C19.9L22%2C44L0%2C22L0%2C22L0%2C22z'%20fill%3D'%23002536'%2F%3E%3C%2Fsvg%3E");

}

.swiper-button-next {
    background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2027%2044'%3E%3Cpath%20d%3D'M27%2C22L27%2C22L5%2C44l-2.1-2.1L22.8%2C22L2.9%2C2.1L5%2C0L27%2C22L27%2C22z'%20fill%3D'%23002536'%2F%3E%3C%2Fsvg%3E");
}

@media screen and #{breakpoint(medium down)} {
    .swiper-button-prev, .swiper-button-next {
        width: 30px;
        height: 20px;
        margin-top: -10px;
        background-size: 30px 20px;
    }
}

.swiper-container {
    width: 100%;
    height: auto;
    margin-left: auto;
    margin-right: auto;
}

#gallery {
    .gallery-container {
        margin-bottom: 100px;
        @media screen and #{breakpoint(large)} {
            .large-image, .gallery {
                height: 800px;
            }
        }
    }

    .large-image {
        margin: 0 auto;
        padding-bottom: 50px;

        .swiper-gallery-horizontal {
            display: none;
        }

        @media screen and #{breakpoint(xslarge down)} {
            .swiper-gallery-horizontal {
                display: block;
                text-align: center;
                margin: 0 auto;
            }
            .swiper-gallery {
                display: none;
            }
        }

        .legend {
            font-size: 16px;
            margin-top: 10px;
        }
    }
}

.gallery {
    width: 100%;
    position: relative;

    .swiper-slide {
        cursor: pointer;
        opacity: 0.8;

        &:first-child {
            opacity: 1;
        }
    }

    @media screen and #{breakpoint(large)} {
        .swiper-button-prev {
            background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2027%2044'%3E%3Cpath%20d%3D'M0%2C22L22%2C0l2.1%2C2.1L4.2%2C22l19.9%2C19.9L22%2C44L0%2C22L0%2C22L0%2C22z'%20fill%3D'%2300000'%2F%3E%3C%2Fsvg%3E");
            transform: rotate(90deg);
            margin: 0 auto;
            top: -30px !important;
            left: 0;
            right: 0;
            position: absolute;
        }
        .swiper-button-next {
            background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2027%2044'%3E%3Cpath%20d%3D'M27%2C22L27%2C22L5%2C44l-2.1-2.1L22.8%2C22L2.9%2C2.1L5%2C0L27%2C22L27%2C22z'%20fill%3D'%23000000'%2F%3E%3C%2Fsvg%3E");
            position: absolute;
            transform: rotate(90deg);
            margin: 0 auto;
            top: auto;
            margin-top: 0px;
            left: 0;
            right: 0;
            bottom: -30px !important;
        }

    }

    .swiper-gallery {
        height: 100%;

        .swiper-slide {
            text-align: center;
            font-size: 18px;
            background: #fff;
            /* Center slide text vertically */
            display: -webkit-box;
            display: -ms-flexbox;
            display: -webkit-flex;
            display: flex;
            -webkit-box-pack: center;
            -ms-flex-pack: center;
            -webkit-justify-content: center;
            justify-content: center;
            -webkit-box-align: center;
            -ms-flex-align: center;
            -webkit-align-items: center;
            align-items: center;
        }
    }

    .swiper-gallery-horizontal {
        display: none;
    }

    @media screen and #{breakpoint(xslarge down)} {
        .swiper-gallery-horizontal {
            display: block;
            text-align: center;
        }
        .swiper-gallery {
            display: none;
        }
    }

}

.swiper-header {
    .swiper-slide {
        img {
            width: 100% !important;
        }

        background-position: center;
        background-size: cover;
    }
}

.swiper-category, .slide-images, .slide-images-shop {
    min-height: 60px;

    .swiper-wrapper {
        .swiper-slide {
            a {
                font-size: 1em;
            }
        }
    }

    .swiper-button-next, .swiper-button-prev {
        position: absolute;
        top: 50%;
        width: 40px;
        height: 20px;
        margin-top: -10px;
        z-index: 10;
        cursor: pointer;
        background-size: 40px 20px;
        background-position: center;
    }

    margin-bottom: 40px;

    .swiper-pagination, .swiper-pagination-shop {
        bottom: 0;
        position: absolute;
        text-align: center;
        .swiper-pagination-bullet {
            transform: scale(1.1);
            cursor: pointer;
        }

        .swiper-pagination-bullet-active {
            background: $secondaryColor;
            transform: scale(1.1);
            cursor: pointer;
        }
    }
}
