{% extends 'base.html.twig' %}
{% block title %}{% trans from 'meta' %}homepage.title{% endtrans %}{% endblock %}
{% block meta %}
    <meta name="robots" content="index,follow">
    <meta name="description" lang="{{ app.request.locale }}"
          content="{% trans from 'meta' %}homepage.description{% endtrans %}">
    <meta property="og:site_name" content="{% trans from 'meta' %}homepage.title{% endtrans %}">
    <meta property="og:title" content="{% trans from 'meta' %}homepage.title{% endtrans %}">
    <meta property="og:type" content="website">
    <meta property="og:url" content="{{ app.request.uri }}">
    <meta property="og:image" content="{{ absolute_url('bundles/cpcreationtheme1/images/logo.jpg') }}">
    <meta property="og:locale" content="{{ app.request.locale }}">
    <meta property="og:image:type" content="image/jpeg">
    <meta property="og:image:width" content="600">
    <meta property="og:image:height" content="450">
    <meta property="og:description"
          content="{% trans from 'meta' %}homepage.description{% endtrans %}">
    <link rel="canonical" href="{{  absolute_url(path('homepage')) }}">
    <link rel="home" href="{{  absolute_url(path('homepage')) }}" >
{% endblock meta %}
{% block submenu %}
    {% if newsletter %}
        <ul class="sub-menu">
            <li>{{ 'newsletter' | trans({'%url%' : newsletter.file.path | file_path }) | raw }}</li>
        </ul>
    {% endif %}
{% endblock %}
{% block header_top %}
    <div data-responsive-background-image>
        <img class="background-image" alt="{% trans from 'meta' %}company_name{% endtrans %}" srcset="
         {{ asset('bundles/cpcreationtheme1/images/background/verify.jpg') | imagine_filter('relative_widen_1024_filter_default') }} 1024w,
         {{ asset('bundles/cpcreationtheme1/images/background/verify.jpg') | imagine_filter('relative_widen_1600_filter_default') }} 1600w"
             src="{{ asset('bundles/cpcreationtheme1/images/background/verify.jpg') | imagine_filter('relative_widen_1600_filter_default') }}">
    </div>
{% endblock %}
{% block header_bottom %}
    <h1 class="hidden">{% trans from 'meta' %}company_name{% endtrans %}</h1>
    <img class="logo" src="{{ asset('bundles/cpcreationtheme1/images/logo.svg') }}"
         alt="Logo {% trans from 'meta' %}company_name{% endtrans %}">
    <a href="#homepage" class="animation-mouse animated fadeIn">
        <div class="mouse">
            <div class="roll"></div>
            <div class="rollshadow"></div>
        </div>
    </a>
{% endblock %}
{% block content %}
    <section id="homepage">
        <div class="citation grid-container">
            <div class="container">
                <p class="phrase">« {% trans %}home.citation{% endtrans %} »</p>
                <p class="author">{% trans %}home.citation_author{% endtrans %}</p>
                {{ 'home.intro'|trans|raw }}
            </div>
        </div>
        <div class="photos grid-x small-up-1 medium-up-2 xsxlarge-up-2 xlarge-up-3 xxxlarge-up-3">
            <div class="cell">
                <figure class="effect-ming img-effect effect_color2">
                    <img srcset="
                    {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_home.jpg'| imagine_filter('relative_widen_512_filter_default')) }} 1024w,
                    {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_home.jpg'| imagine_filter('relative_widen_600_filter_default')) }} 1200w,
                    {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_home.jpg' | imagine_filter('relative_widen_512_filter_default')) }} 1500w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_home.jpg' | imagine_filter('relative_widen_600_filter_default')) }} 1800w"
                         src="{{ asset('bundles/cpcreationtheme1/images/homepage/homepage_home.jpg'| imagine_filter('relative_widen_512_filter_default')) }}"
                         alt="{% trans from 'meta' %}home.title{% endtrans %}">
                    <figcaption>
                        <h2>{% trans %}homepage.0.title{% endtrans %}</h2>
                        <p>{% trans %}homepage.0.subtitle{% endtrans %}</p>
                        <a href="{{ path('home') }}"
                           title="{{ 'maison'|trans([],'menu') }} - {% trans %}company{% endtrans %}"></a>
                    </figcaption>
                </figure>
            </div>
            <div class="cell">
                <figure class="effect-ming img-effect effect_color1">
                    <img srcset="
                         {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_cuvees.jpg'| imagine_filter('relative_widen_512_filter_default')) }} 1024w,
                    {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_cuvees.jpg'| imagine_filter('relative_widen_600_filter_default')) }} 1200w,
                    {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_cuvees.jpg' | imagine_filter('relative_widen_512_filter_default')) }} 1500w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_cuvees.jpg' | imagine_filter('relative_widen_600_filter_default')) }} 1800w"
                         src="{{ asset('bundles/cpcreationtheme1/images/homepage/homepage_cuvees.jpg'| imagine_filter('relative_widen_512_filter_default')) }}"
                         alt="{% trans from 'meta' %}cuvee.title{% endtrans %}">
                    <figcaption>
                        <h2>{% trans %}homepage.2.title{% endtrans %}</h2>
                        <p>{% trans %}homepage.2.subtitle{% endtrans %}</p>
                        <a href="{{ path('cuvees') }}" title="{% trans from 'meta' %}cuvee.title{% endtrans %}"></a>
                    </figcaption>
                </figure>
            </div>
            <div class="cell">
                <figure class="effect-ming img-effect effect_color2">
                    <img srcset="
                         {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_season.jpg'| imagine_filter('relative_widen_512_filter_default')) }} 1024w,
                    {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_season.jpg'| imagine_filter('relative_widen_600_filter_default')) }} 1200w,
                    {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_season.jpg' | imagine_filter('relative_widen_512_filter_default')) }} 1500w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_season.jpg' | imagine_filter('relative_widen_600_filter_default')) }} 1800w"
                         src="{{ asset('bundles/cpcreationtheme1/images/homepage/homepage_season.jpg'| imagine_filter('relative_widen_512_filter_default')) }}"
                         alt="{% trans from 'meta' %}season.title{% endtrans %}">
                    <figcaption>
                        <h2>{% trans %}homepage.1.title{% endtrans %}</h2>
                        <p>{% trans %}homepage.1.subtitle{% endtrans %}</p>
                        <a href="{{ path('seasons') }}" title="{% trans from 'meta' %}season.title{% endtrans %}"></a>
                    </figcaption>
                </figure>
            </div>
            <div class="cell">
                <figure class="effect-ming img-effect effect_color3">
                    <img srcset="
                    {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_news.jpg'| imagine_filter('relative_widen_512_filter_default')) }} 1024w,
                    {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_news.jpg'| imagine_filter('relative_widen_600_filter_default')) }} 1200w,
                    {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_news.jpg' | imagine_filter('relative_widen_512_filter_default')) }} 1500w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_news.jpg' | imagine_filter('relative_widen_600_filter_default')) }} 1800w"
                         src="{{ asset('bundles/cpcreationtheme1/images/homepage/homepage_news.jpg'| imagine_filter('relative_widen_512_filter_default')) }}"
                         alt="{% trans from 'meta' %}shop.title{% endtrans %}">
                    <figcaption>
                        <h2>{% trans %}homepage.3.title{% endtrans %}</h2>
                        <p>{% trans %}homepage.3.subtitle{% endtrans %}</p>
                        <a href="{{ path('news') }}" title="{% trans from 'meta' %}shop.title{% endtrans %}"></a>
                    </figcaption>
                </figure>
            </div>
            <div class="cell">
                <figure class="effect-ming img-effect effect_color2">
                    <img srcset="
                         {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_gallery.jpg'| imagine_filter('relative_widen_512_filter_default')) }} 1024w,
                    {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_gallery.jpg'| imagine_filter('relative_widen_600_filter_default')) }} 1200w,
                    {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_gallery.jpg' | imagine_filter('relative_widen_512_filter_default')) }} 1500w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_gallery.jpg' | imagine_filter('relative_widen_600_filter_default')) }} 1800w"
                         src="{{ asset('bundles/cpcreationtheme1/images/homepage/homepage_gallery.jpg'| imagine_filter('relative_widen_512_filter_default')) }}"
                         alt="{% trans from 'meta' %}library.title{% endtrans %}">
                    <figcaption>
                        <h2>{% trans %}homepage.4.title{% endtrans %}</h2>
                        <p>{% trans %}homepage.4.subtitle{% endtrans %}</p>
                        <a href="{{ path('library') }}" title="{% trans from 'meta' %}library.title{% endtrans %}"></a>
                    </figcaption>
                </figure>
            </div>
            <div class="cell">
                <figure class="effect-ming img-effect effect_color3">
                    <img srcset="
                           {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_shop.jpg'| imagine_filter('relative_widen_512_filter_default')) }} 1024w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_shop.jpg'| imagine_filter('relative_widen_600_filter_default')) }} 1200w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_shop.jpg' | imagine_filter('relative_widen_512_filter_default')) }} 1500w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_shop.jpg' | imagine_filter('relative_widen_600_filter_default')) }} 1800w"
                         src="{{ asset('bundles/cpcreationtheme1/images/homepage/homepage_shop.jpg'| imagine_filter('relative_widen_512_filter_default')) }}"
                         alt="{% trans from 'meta' %}shop.title{% endtrans %}">
                    <figcaption>
                        <h2>{% trans %}homepage.5.title{% endtrans %}</h2>
                        <p>{% trans %}homepage.5.subtitle{% endtrans %}</p>
                        <a href="{{ path('shop') }}" title="{% trans from 'meta' %}shop.title{% endtrans %}"></a>
                    </figcaption>
                </figure>
            </div>
            <div class="cell">
                <figure class="effect-ming img-effect effect_color2">
                    <img srcset="
                           {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_payment.jpg'| imagine_filter('relative_widen_512_filter_default')) }} 1024w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_payment.jpg'| imagine_filter('relative_widen_600_filter_default')) }} 1200w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_payment.jpg' | imagine_filter('relative_widen_512_filter_default')) }} 1500w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_payment.jpg' | imagine_filter('relative_widen_600_filter_default')) }} 1800w"
                         src="{{ asset('bundles/cpcreationtheme1/images/homepage/homepage_payment.jpg'| imagine_filter('relative_widen_512_filter_default')) }}"
                         alt="{% trans from 'meta' %}shop.title{% endtrans %}">
                    <figcaption>
                        <h2>{% trans %}homepage.6.title{% endtrans %}</h2>
                        <p>{% trans %}homepage.6.subtitle{% endtrans %}</p>
                        <a href="{{ path('payment') }}" title="{% trans from 'meta' %}payment.title{% endtrans %}"></a>
                    </figcaption>
                </figure>
            </div>
            <div class="cell">
                <figure class="effect-ming img-effect effect_color1">
                    <img srcset="
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_find_us.jpg'| imagine_filter('relative_widen_512_filter_default')) }} 1024w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_find_us.jpg'| imagine_filter('relative_widen_600_filter_default')) }} 1200w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_find_us.jpg' | imagine_filter('relative_widen_512_filter_default')) }} 1500w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_find_us.jpg' | imagine_filter('relative_widen_600_filter_default')) }} 1800w"
                         src="{{ asset('bundles/cpcreationtheme1/images/homepage/homepage_find_us.jpg'| imagine_filter('relative_widen_512_filter_default')) }}"
                         alt="{% trans from 'meta' %}find-us.title{% endtrans %}">
                    <figcaption>
                        <h2>{% trans %}homepage.7.title{% endtrans %}</h2>
                        <p>{% trans %}homepage.7.subtitle{% endtrans %}</p>
                        <a href="{{ path('find-us') }}" title="{% trans from 'meta' %}find-us.title{% endtrans %}"></a>
                    </figcaption>
                </figure>
            </div>
            <div class="cell">
                <figure class="effect-ming img-effect effect_color2">
                    <img srcset="
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_gite.jpg'| imagine_filter('relative_widen_512_filter_default')) }} 1024w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_gite.jpg'| imagine_filter('relative_widen_600_filter_default')) }} 1200w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_gite.jpg' | imagine_filter('relative_widen_512_filter_default')) }} 1500w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_gite.jpg' | imagine_filter('relative_widen_600_filter_default')) }} 1800w"
                         src="{{ asset('bundles/cpcreationtheme1/images/homepage/homepage_gite.jpg'| imagine_filter('relative_widen_512_filter_default')) }}"
                         alt="{% trans from 'meta' %}contact.title{% endtrans %}">
                    <figcaption>
                        <h2>{% trans %}homepage.8.title{% endtrans %}</h2>
                        <p>{% trans %}homepage.8.subtitle{% endtrans %}</p>
                        <a href="{{ path('cottage', { slug : cottages[0].slug }) }}" title="{% trans from 'meta' %}gite.title{% endtrans %}"></a>
                    </figcaption>
                </figure>
            </div>
            <div class="cell">
                <figure class="effect-ming img-effect effect_color3">
                    <img srcset="
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_contact.jpg'| imagine_filter('relative_widen_512_filter_default')) }} 1024w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_contact.jpg'| imagine_filter('relative_widen_600_filter_default')) }} 1200w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_contact.jpg' | imagine_filter('relative_widen_512_filter_default')) }} 1500w,
                        {{ asset('bundles/cpcreationtheme1/images/homepage/homepage_contact.jpg' | imagine_filter('relative_widen_600_filter_default')) }} 1800w"
                         src="{{ asset('bundles/cpcreationtheme1/images/homepage/homepage_contact.jpg'| imagine_filter('relative_widen_512_filter_default')) }}"
                         alt="{% trans from 'meta' %}contact.title{% endtrans %}">
                    <figcaption>
                        <h2>{% trans %}homepage.9.title{% endtrans %}</h2>
                        <p>{% trans %}homepage.9.subtitle{% endtrans %}</p>
                        <a href="{{ path('contact') }}" title="{% trans from 'meta' %}contact.title{% endtrans %}"></a>
                    </figcaption>
                </figure>
            </div>
            <div class="cell auto">
                <img src="{{ asset('bundles/cpcreationtheme1/images/logo_n.svg') }}"
                     alt="Logo {% trans from 'meta' %}company_name{% endtrans %}">
            </div>
        </div>
    </section>
{% endblock %}
{% block modal %}
    {% if popup %}
        {% include '_popup.html.twig' with { 'popup' : popup} only %}
    {% endif %}
{% endblock %}
