[data-responsive-background-image] {
  background-size: cover;
  background-position: right center;
  background-repeat: no-repeat;
  display: inline-block;
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0;
  z-index: -1;
  &:before {
    content: '';
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    background-image: radial-gradient(transparent,rgba(0,0,0,0.3));
  }
}

[data-responsive-background-image] {
  img.background-image {
    display: none;
  }
}

header {
  h1 {
    text-transform: uppercase;
    text-align: center;
  }
  .title {
    margin-top: 50px;
  }
  position: relative;
  &.homepage {
    @media screen and #{breakpoint(large)} {
      height: 100vh;
    }
    @media screen and #{breakpoint(xslarge down)} {
      height: 600px;
    }
  }
  .picto {
    display: flex;
    @media screen and #{breakpoint(xslarge down)} {
      align-items: center;
    }
    @media screen and #{breakpoint(medium down)} {
      padding: 0;
    }
    @media screen and #{breakpoint(large)} {
      align-items: flex-end;
      padding: 5px;
    }
    img{
      max-width: 30px;
      width: 50%;
    }
    a{
      text-align: center;
      width: 100%;
    }
  }
  .logo {
    transform: translate(-50%, -50%);
    position: absolute;
    left: 50%;
    top: 50%;
    width: 80%;
    max-width: 600px;
  }
}