.reveal-overlay {
  z-index: 999999;
}

#popupNews {
  outline-style: none;
  box-shadow: none;
  border-color: transparent;
  position: relative;
  .image-popup {
    margin: 0 auto;
    text-align: center;
  }
  .popup-text-content {
    display: flex;
    flex-direction: row;
    flex-wrap: wrap;
    p {
      text-align: justify;
    }
    .btn-popup {
      margin-top: 20px;
    }
    button {
      color: white;
      cursor: pointer;
      background-color: $primary;
      padding: 10px;
      margin: 0 5px;
      width: 150px;
    }
    button:hover {
      box-shadow: 8px 8px 12px rgba(0, 0, 0, .29);
    }
  }
}

@media screen and #{breakpoint(xslarge down)} {
  #popupNews {
    animation: 1.5s fadeIn;
    -webkit-animation: 1.5s fadeIn;
    .align-middle {
      padding-top: 30px;
    }
    .popup-text-content {
      h2 {
        margin: 20px auto;
      }
      .btn-popup {
        margin: 0 auto;
      }
    }
  }
}

@media screen and #{breakpoint(large)} {
  #popupNews {
    animation: 1.5s fadeInUp;
    -webkit-animation: 1.5s fadeInUp;
    .popup-text-content {
      h2 {
        margin: 20px 0;
      }
      .btn-popup {
        margin-left: auto;
      }
    }
  }
}


.video-popup {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  border: none;
}

.video-popup-container {
  position: relative;
  width: 100%;
  max-width: 560px; /* optionnel, pour limiter la largeur */
  aspect-ratio: 16 / 9; /* Ajuste automatiquement la hauteur pour un format 16:9 */
  text-align: center;
  video {
    max-width: 80%;
    max-height: 400px
  }
}

.popup-text-content {
  padding: 0 20px;
}

.only-text-popup {
  display: flex;
  flex-direction: column !important;
}