button.payment{
    position: relative;
    text-transform: uppercase;
    border-radius: 50px;
    width: 100%;
    margin-bottom: 0;
    color: #ffffff;
    transition: all .3s;
    background-color: transparent;
    overflow: hidden;
    &:hover, &:focus {
        color: white;
        background-color: transparent !important;
        &:after {
            background: #000;
            height: 100%;
            width: 200%;
        }
    }
    &:before {
        background-color: $colorShop;
        width: 100%;
        left: 0;
        content: "";
        height: 100%;
        border-radius: 50px;
        position: absolute;
        top: 0;
        z-index: -1;
    }
    &:after {
        -webkit-transition: all .3s;
        -moz-transition: all .3s;
        -o-transition: all .3s;
        transition: all .3s;
        left: -50%;
        border-radius: 50px;
        transform: skew(50deg);
        transition-duration: .6s;
        transform-origin: top left;
        width: 0;
        content: "";
        height: 100%;
        position: absolute;
        top: 0;
        z-index: -1;
    }
}
#payment-form{
    .input-group {
        margin-bottom: 0rem;
    }
    margin-bottom: 100px;
}

section.payment{
    button{
        position: relative;
        input{
            position: absolute;
            width: 100%;
            height: 100%;
            opacity: 0;
            left: 0;
            top: 0;
            z-index: 10;
        }
    }
}
