<div class="text-center">
    <div class="slide-images-shop align-center swiper-container">
        <div class="swiper-wrapper">
            <div class="swiper-slide">
                <img class="align-center"
                     src="{{ asset(item.image.path) | imagine_filter('relative_heighten_586_filter') }}"
                     alt="{{ item.name }} {% if item.quality %}{{ item.quality }}{% endif %}">
            </div>
            {% for imageItem in item.images %}
                <div class="swiper-slide">
                    <img src="{{ asset(imageItem.image.path) | imagine_filter('relative_heighten_586_filter') }}"
                         alt="{{ item.name }}">
                </div>
            {% endfor %}
        </div>
        {% if item.images|length > 0 %}
            <div class="swiper-pagination-shop"></div>
        {% endif %}
    </div>
    {% if not item.isShowInfoShopOnlyOnPanel %}
        {% if item.assemblages %}
            <p>
                <b>Assemblage : </b>
                {% for assemblage in item.assemblages %}
                    {{ assemblage | raw }} {% if loop.last == false %}-{% endif %}
                {% endfor %}
            </p>
        {% endif %}
        {{ item.description }}
        {% if item.dosage %}
            <p><b>Dosage : </b>{{ item.dosage | raw |e}}</p>
        {% endif %}
        {% if item.tasting %}
            <p><b>Dégustation : </b>{{ item.tasting | raw |e}}</p>
        {% endif %}
        {% if item.winemaking %}
            {% for wine in item.winemaking %}
                <p><b>Temps de vieillissement :</b> {{ wine | raw |e}}</p>
            {% endfor %}
        {% endif %}
    {% endif %}
    {% if item.infoShop %}
        <p>{{ item.infoShop|raw|e }}</p>
    {% endif %}
    {% for award in item.awards %}
        <img class="award-panel" src="{{ asset(award.image.path)|imagine_filter('relative_heighten_100_filter') }}"
             alt="{{ award.title }}" data-tooltip-js
             title="{{ award.title }} - {{ award.description }}">
    {% endfor %}
</div>
