body {
  font-family: 'Museo Slab', sans-serif;
  font-weight: 100;
}
h1, h2 {
  color: black;
  font-family: 'Museo Slab', sans-serif;
  font-weight: 500;
  letter-spacing: 0.2rem;
  margin: 0;
}

h3, h4, h5, h6 {
  color: black;
  font-family: 'Museo Slab', sans-serif;
  font-weight: 500;
  letter-spacing: 0.2rem;
  margin: 0;
}

h2 {
  font-size: 2.5rem;
  @media screen and #{breakpoint(medium down)} {
    font-size: 1.6rem;
  }
}

h3 {
  font-size: 2rem;
  @media screen and #{breakpoint(medium down)} {
    font-size: 1.3rem;
  }
}
h4 {
    font-size: 1.6rem;
    @media screen and #{breakpoint(medium down)} {
        font-size: 1.2rem;
    }
}
p {
  font-size: 1.1em;
  margin-bottom: 0.6rem;
  .strong {
    font-weight: 500;
  }
  &.subtitle {
    font-size: 120%;
  }
  @media screen and #{breakpoint(medium down)} {
    font-size: 1em;
  }
}
strong {
  font-weight: 500;
}
a {
  text-decoration: underline;
  color: $primary;
  &:hover {
    color: black;
  }
}

label.required:before {
  content: "* ";
}

.container {
  width: 100%;
  max-width: 970px;
  margin: 0 auto;
}

img, picture, figure{
    image-rendering: -webkit-optimize-contrast;
}
