<section class="payment payment-return grid-x grid-margin-x">
    <div class="small-12">
        <h3>{{ msg }}</h3>
        {% if error is not null %}
            <p>{{ error }}</p>
        {% endif %}
        <div class="cell small-6 text-left">
            <a href="{{ path('payment') }}" class="success button"><i class="fas fa-angle-left"></i> {% trans %} payment.back {% endtrans %}</a>
        </div>
    </div>
</section>
