#homepage {
    padding-top: 120px;

    .photos {
        @media screen and #{breakpoint(xxxlarge)} {
            justify-content: center;
        }
        margin-top: 120px;

        .auto {
            display: flex;
            text-align: center;
            align-items: center;
            justify-content: center;

            img {
                width: 500px;
                max-width: 50%;
            }
        }
    }

    figure.img-effect {
        &:hover {
            img {
                -webkit-filter: grayscale(100%);
                filter: grayscale(100%);
                opacity: 0.5;
            }
        }

        p {
            font-size: 88%;
        }

        h2 {
            color: white;
            font-size: 1.2rem;
        }
    }
}

#la-maison {
    h2 {
        text-transform: uppercase;
    }

    .text {
        margin-top: 50px;

        p {
            text-align: justify;
        }
    }

    article {
        margin-top: 50px;
        margin-bottom: 50px;
    }

    margin-bottom: 100px;

    .photos {
        margin-top: 40px;
    }
}

footer {
    padding: 30px 0 10px 0;
    background-color: $primary;
    color: $footer;

    .contact {
        @media screen and #{breakpoint(xslarge down)} {
            text-align: center;
            margin-top: 20px;
        }
        @media screen and #{breakpoint(large)} {
            text-align: left;
        }
    }

    .social {
        text-align: center;
        margin-top: 10px;
        margin-left: 0;

        li {
            &:not(:first-child) {
                margin-left: 6px;
            }

            display: inline-block;

            img {
                width: 50px;
            }
        }
    }

    a {
        text-decoration: none;
        color: white;

        &:hover {
            color: #d7d7d7;
        }
    }
}

#les-cuvees {
    margin-top: 50px;

    .separator {
        margin: 0;
    }

    h2 {
        margin: 0;
        line-height: 2.5rem;
        text-transform: uppercase;
    }

    .cuvee-content {
        margin-top: 20px;
        @media screen and #{breakpoint(xslarge down)} {
            padding-right: 0.9375rem;
            padding-left: 0.9375rem;
            text-align: center;
            max-width: 570px;
            margin: 0 auto;
            margin-bottom: 100px;
        }
        @media screen and #{breakpoint(small only)} {
            max-width: 100%;
        }
    }

    .cuvee-content.large-order-1 {
        @media screen and #{breakpoint(large)} {
            margin-left: 1.875rem;
        }

        .cuvee-text {
            @media screen and #{breakpoint(large)} {
                padding-right: 1.875rem;
            }
            @media screen and #{breakpoint(xslarge down)} {
                margin-top: 20px;
            }
        }
    }

    .cuvee-image {
        position: relative;
        @media screen and #{breakpoint(xslarge down)} {
            margin: 0 auto;
        }
    }

    .cuvee-image.large-order-1 {
        @media screen and #{breakpoint(large)} {
            margin-left: 1.875rem;
        }
    }

    .cuvee-content.large-order-2 {
        .cuvee-text {
            @media screen and #{breakpoint(large)} {
                padding-left: 1.875rem;
            }
            @media screen and #{breakpoint(xslarge down)} {
                margin-top: 20px;
            }
        }
    }

    .cuvee-description {
        margin-top: 20px;
    }

    span.cuvee-header {
        font-size: 1.2rem;
        text-transform: uppercase;
        color: var(--color-cuvee);
    }

    p {
        text-align: justify;
        font-size: 0.95rem;
        @media screen and #{breakpoint(large only)} {
            font-size: 0.81rem;
        }
    }

    a {
        text-decoration: underline;
        color: $primary;

        &:hover {
            color: $black;
        }
    }

    .awards {
        text-align: left;
        margin: 0;
        @media screen and #{breakpoint(xslarge down)} {
            text-align: center;
        }

        li {
            display: inline-block;

            &:after {
                content: '';
                padding-right: 20px;
            }
        }
    }
}

#gallery {
    margin-bottom: 50px;
    margin-top: 50px;

    .instagram {
        margin-top: 60px;
    }

    p.or {
        font-size: 4em;
        text-align: center;
    }
}

#contact {
    a {
        color: #000000;

        &:hover {
            color: gray;
        }
    }
}

#header_payment {
    margin-top: 50px;
    margin-bottom: 50px;
}

section.shop {
    margin-top: 40px;

    h4 {
        margin: 0;
        color: black;
    }

    h4.cuvee-name {
        color: white
    }

    #codePriceForm {
        margin-bottom: 40px;
    }
}

section.legals {
    margin: 100px 0;
}

section.depot {
    margin-top: 50px;

    article {
        h2 {
            text-transform: uppercase;
            margin-bottom: 25px;
        }

        @media screen and #{breakpoint(xslarge down)} {
            margin-bottom: 50px;
        }

    }

    #salons {
        ul {
            li {
                margin-bottom: 1.5rem;
                margin-top: 1.5rem;
                @media screen and #{breakpoint(large)} {
                    text-align: center;
                }
                @media screen and #{breakpoint(medium down)} {
                    text-align: justify;
                }
            }
        }

        .depot-name {
            font-size: 1.5rem;
        }
    }

    .depot-container {
        h2 {
            line-height: 2.5rem;
            text-transform: uppercase;
            margin-bottom: 20px;
            margin-left: auto;
            margin-right: auto;
            @media screen and #{breakpoint(medium down)} {
                margin-top: 50px;
            }
        }

        @media screen and #{breakpoint(xslarge down)} {
            .large-6 {
                width: 100%;
            }
        }

    }

    .depotMap-container {
        position: relative;
        height: 800px;
        @media screen and #{breakpoint(xslarge down)} {
            width: 100%;
        }
    }

    .depotMap {
        height: 785px;
        @media screen and #{breakpoint(xslarge down)} {
            height: 800px;
        }
    }

    div.depot {
        margin-bottom: 0.9em;
        font-size: 0.9em;
    }
}

#les-actualites {
    iframe {
        border: 0;
    }

    margin-top: 50px;

    article {
        margin-left: 0;
        margin-right: 0;

        .article-media {
            position: relative;
            margin-bottom: 20px;
        }

        .article-border {
            height: 25px;
            background-color: $secondaryColor;
        }

        margin-bottom: 120px;

        .article-content {
            margin-top: 20px;

            .article-infos {
                @media screen and #{breakpoint(small only)} {
                    text-align: center;
                    .infos {
                        display: inline-block;
                    }
                    margin-bottom: 10px;
                }
                text-align: right;

                .infos {
                    font-style: italic;
                    margin-bottom: 0;
                }

                .article-category {
                    font-weight: bold;
                }
            }

            .article-date {
                font-weight: bold;
                color: $primary;
            }
        }

        [class='more'] {
            display: none;
        }

        .line-more {
            display: flex;
            align-items: center;

            .line {
                &:before {
                    display: block;
                    border-bottom: 2px solid #dfdfdf;
                    content: "";
                    z-index: 2;
                }

                width: 80%
            }

            .text {
                width: 20%;
                text-align: right;
                order: 2;
                color: $primary;
                text-decoration: underline;
                cursor: pointer;

                &.open {
                    &:after {
                        margin-left: 5px;
                        content: '\003e';
                        transform: rotate(-90deg);
                        display: inline-block;
                    }
                }

                &.close {
                    &:after {
                        margin-left: 5px;
                        content: '\003e';
                        transform: rotate(90deg);
                        display: inline-block;
                    }
                }
            }
        }
    }

    .empty {
        min-height: 400px;
    }
}

section.season {
    margin-top: 80px;

    .background-odd {
        background-color: $backgoundColorLight;
    }

    .background-even {
        background-color: white;
    }

    article {
        padding: 70px 0;

        p {
            text-align: justify;
        }
    }

    span.month {
        text-transform: uppercase;
        letter-spacing: 4px;
    }

    .season-content {
        margin-top: 40px;

        .season-menu {
            font-size: 20px;
            letter-spacing: 2px;
            text-transform: uppercase;
            @media screen and (max-width: 570px) {
                font-size: 14px;
            }
        }
    }

    .season-title {
        position: relative;
        z-index: 1;
        margin-top: 50px;

        &:before {
            border-top: 2px solid black;
            content: "";
            margin: 0 auto; /* this centers the line to the full width specified */
            position: absolute; /* positioning must be absolute here, and relative positioning must be applied to the parent */
            top: 32%;
            left: 0;
            right: 0;
            bottom: 0;
            width: 100%;
            z-index: -1;
        }

        h2 {
            color: black;
            padding: 0 50px;
            display: inline-block;
            text-transform: uppercase;

        }
    }

    .season-img {
        position: relative;
        @media screen and #{breakpoint(medium down)} {
            width: 100%;
            padding-right: 0;
            padding-left: 0;

        }
    }
}

.footer-content {
    margin-top: 12px;
}

.labels {
    @media screen and #{breakpoint(xslarge down)} {
        text-align: center;
    }
    @media screen and #{breakpoint(large)} {
        text-align: right;
    }

    .grid-x {
        align-items: center;
        text-align: center;
    }

    img {
        max-height: 120px;
    }
}

@media screen and #{breakpoint(xslarge down)} {
    .labels {
        margin-top: 15px;
    }
    .labels, .social {
        margin-bottom: 20px;
    }
}

#cottage {
    #descriptive {
        padding: 60px 0;
        background-color: $primary;
        color: white;
        text-align: justify;

        h2 {
            text-transform: uppercase;
            text-align: center;
            color: white;
            padding-bottom: 60px
        }
    }

    .rooms {
        h2 {
            @media screen and #{breakpoint(large down)} {
                text-align: center;
            }
            text-transform: uppercase;
        }

        p {
            text-align: justify;
        }

        article {
            @media screen and #{breakpoint(large down)} {
                .room {
                    align-items: center;
                }
            }
            margin: 100px 0;

            .content-left-room {
                position: relative;

                .content-room {
                    padding: 20px 0;
                }

                .content-line {
                    position: absolute;
                    bottom: 0;
                    width: 100%;
                    border-bottom: 1px solid black;
                }
            }
        }
    }

    #booking {
        background-color: $backgoundColorLight;
        padding: 60px 0;

        .content-price-header {
            h2 {
                text-transform: uppercase;
                display: inline-block;
                @media screen and #{breakpoint(large down)} {
                    text-align: center;
                    display: block;
                }
            }

            img {
                display: inline-block;
                width: 150px;
                @media screen and #{breakpoint(large down)} {
                    text-align: center;
                    display: block;
                    margin: 0 auto;
                }
            }

            @media screen and #{breakpoint(large down)} {
                margin-bottom: 60px;
            }
        }

        .content-price {
            @media screen and #{breakpoint(large)} {
                /*padding-left: 20px;*/
            }

            p {
                @media screen and #{breakpoint(large)} {
                    text-align: justify;
                }
                @media screen and #{breakpoint(xslarge down)} {
                    text-align: center;
                }
            }

            a.btn-contact {
                margin-top: 60px;
                display: inline-block;
                background-color: $primary;
                color: white;
                padding: 20px;
                width: 100%;
                text-align: center;
                text-transform: uppercase;
                font-size: 120%;
                text-decoration: none;

                &:hover {
                    box-shadow: 8px 8px 12px rgba(0, 0, 0, .29);
                }
            }
        }
    }
}

.payment, .form-cart {
    margin-bottom: 100px;
}
