.fullscreen-bg__video, #videoWrapper .fullscreen-bg {
    z-index: 1;
    width: 100vw;
    height: 56.25vw; /* Given a 16:9 aspect ratio, 9/16*100 = 56.25 */
    min-height: 100vh;
    min-width: 177.77vh; /* Given a 16:9 aspect ratio, 16/9*100 = 177.77 */
    position: absolute;
    /*@media screen and (max-width: 640px) {
        left: -500px;
    }
    @media screen and (max-width: 375px) {
        left: -200px;
    }*/
}
