.animation-mouse {
  cursor: pointer;
  animation-duration: 4s;

  @media screen and #{breakpoint(xslarge down)} {
    text-align: right;
    [type='checkbox'] + label {
      margin-right: 0;
      padding-right: 0;
    }
  }
}
.mouse-header {
  position: absolute;
  left: 0;
  right: 0;
  bottom: 30px;
}
.mouse-arrow1, .mouse-arrow2, .mouse-arrow3 {
  position: absolute;
  left: 0;
  right: 0;
  animation-iteration-count: infinite;
}
.mouse-arrow1 {
  bottom: 44px;
  animation-duration: 5s;
  animation-delay: 1s;
}
.mouse-arrow2 {
  bottom: 39px;
  animation-duration: 5s;
  animation-delay: 1.2s;
}
.mouse-arrow3 {
  bottom: 15px;
  animation-duration: 5s;
  animation-delay: 2.4s;
}

/**
 * ----------------------------------------
 * animation mouse scroll
 * ----------------------------------------
 */
.mouse {
  width: 26px;
  height: 40px;
  border-radius: 15px;
  border: 2px solid #fff;
  position: absolute;
  overflow: hidden;
  bottom: 10px;
  left: 0;
  margin: 0 auto;
  right: 0;
}
.mouse .roll {
  position: absolute;
  top: 8px;
  left: 50%;
  width: 4px;
  margin-left: -2px;
  height: 4px;
  border-radius: 4px;
  background: #FFFFFF;
  -webkit-animation: mouseScroll .8s cubic-bezier(.7,0,.3,1) infinite alternate;
  animation: mouseScroll .8s cubic-bezier(.7,0,.3,1) infinite alternate;
  z-index: 2;
}
.mouse .rollshadow {
  position: absolute;
  top: 8px;
  left: 50%;
  width: 4px;
  margin-left: -2px;
  height: 4px;
  background: #aaa;
  border-radius: 4px;
  -webkit-animation: mouseScroll .8s cubic-bezier(.7,0,.3,1) infinite alternate;
  animation: mouseScroll .8s cubic-bezier(.7,0,.3,1) infinite alternate;
  animation-delay: 0s;
  -webkit-animation-delay: 80ms;
  animation-delay: 80ms;
  z-index: 1;
}
@-webkit-keyframes mouseScroll {
  0% {
    -webkit-transform:translateY(0);
    transform:translateY(0)
  }
  100% {
    -webkit-transform:translateY(14px);
    transform:translateY(14px)
  }
}
@keyframes mouseScroll {
  0% {
    -webkit-transform:translateY(0);
    transform:translateY(0)
  }
  100% {
    -webkit-transform:translateY(14px);
    transform:translateY(14px)
  }
}
